@@ -232,7 +232,7 @@ function step1() {
 }
 
 function printstep1form( $dbname = 'wordpress', $uname = 'username', $pwd = 'password', $dbhost = 'localhost', $vhost = 'yes', $prefix = 'wp_' ) {
-	$weblog_title = 'My new WordPress MU Site';
+	$weblog_title = ucfirst( $_SERVER[ 'HTTP_HOST' ] ) . ' Blogs';
 	$email = '';
 	$hostname = $_SERVER[ 'HTTP_HOST' ];
 	if( substr( $_SERVER[ 'HTTP_HOST' ], 0, 4 ) == 'www.' )
@@ -337,6 +337,10 @@ function step2() {
 			case '$base = \'BASE\';':
 				fwrite($handle, str_replace('BASE', $base, $line));
 				break;
+			case "define('SECRET_K":
+			case "define('SECRET_S":
+				fwrite($handle, str_replace('put your unique phrase here', md5( mt_rand() ) . md5( mt_rand() ), $line));
+				break;
 			default:
 				fwrite($handle, $line);
 				break;
@@ -362,9 +366,9 @@ function step3() {
 	$email = $wpdb->escape( $_POST[ 'email' ] );
 	if( $email == '' )
 		die( 'You must enter an email address!' );
-	$weblog_title = $wpdb->escape( $_POST[ 'weblog_title' ] );
 
 	// set up site tables
+	$wpdb->query( "INSERT INTO ".$wpdb->sitemeta." (meta_id, site_id, meta_key, meta_value) VALUES (NULL, 1, 'site_name', '" . $wpdb->escape( $_POST[ 'weblog_title' ] ) . "')" );
 	$wpdb->query( "INSERT INTO ".$wpdb->sitemeta." (meta_id, site_id, meta_key, meta_value) VALUES (NULL, 1, 'admin_email', '".$email."')" );
 	$wpdb->query( "INSERT INTO ".$wpdb->sitemeta." (meta_id, site_id, meta_key, meta_value) VALUES (NULL, 1, 'admin_user_id', '1')" );
 	$wpdb->query( "INSERT INTO ".$wpdb->sitemeta." (meta_id, site_id, meta_key, meta_value) VALUES (NULL, 1, 'registration', 'none')" );
@@ -393,6 +397,8 @@ Thanks!
 --The Team @ SITE_NAME')" );
 	$wpdb->query( "INSERT INTO ".$wpdb->sitemeta." (meta_id, site_id, meta_key, meta_value) VALUES (NULL, 1, 'first_post', 'Welcome to <a href=\"SITE_URL\">SITE_NAME</a>. This is your first post. Edit or delete it, then start blogging!' )" );
 
+	$weblog_title = stripslashes( $_POST[ 'weblog_title' ] );
+
 	$pass = substr( md5( rand() ), 5, 12 );
 	$user_id = wpmu_create_user( 'admin', $pass, $email);
 
@@ -481,18 +487,6 @@ switch($action) {
 		do_htaccess( 'htaccess.dist', '.htaccess', $base, '');
 		step3();
 	break;
-	case "step3":
-		// call createBlog();
-		// create .htaccess
-		// print login info and links.
-		require_once('./wp-config.php');
-		require_once('./wp-admin/upgrade-functions.php');
-		make_db_current_silent();
-		populate_options();
-		do_htaccess( 'htaccess.dist', '.htaccess', $base, '');
-		printheader();
-		step3();
-	break;
 	default:
 		// check that directories are writeable.
 		// create wpmu-settings.php
