@@ -1,25 +1,25 @@
 <?php
 require_once('admin.php');
 
-$title = __('Writing Options');
+$title = __('Writing Settings');
 $parent_file = 'options-general.php';
 
 include('admin-header.php');
 ?>
 
 <div class="wrap">
-<h2><?php _e('Writing Options') ?></h2>
+<h2><?php _e('Writing Settings') ?></h2>
 <form method="post" action="options.php">
-<?php wp_nonce_field('update-options') ?>
-<p class="submit"><input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>
-<table width="100%" cellspacing="2" cellpadding="5" class="optiontable editform">
+<?php wp_nonce_field('writing-options') ?>
+<input type='hidden' name='option_page' value='writing' />
+<table class="form-table">
 <tr valign="top">
-<th width="33%" scope="row"> <?php _e('Size of the post box:') ?></th>
-<td><input name="default_post_edit_rows" type="text" id="default_post_edit_rows" value="<?php form_option('default_post_edit_rows'); ?>" size="2" style="width: 1.5em; " />
+<th scope="row"> <?php _e('Size of the post box') ?></th>
+<td><input name="default_post_edit_rows" type="text" id="default_post_edit_rows" value="<?php form_option('default_post_edit_rows'); ?>" size="2" style="width: 1.5em;" />
 <?php _e('lines') ?></td>
 </tr>
 <tr valign="top">
-<th scope="row"><?php _e('Formatting:') ?></th>
+<th scope="row"><?php _e('Formatting') ?></th>
 <td>
 <label for="use_smilies">
 <input name="use_smilies" type="checkbox" id="use_smilies" value="1" <?php checked('1', get_option('use_smilies')); ?> />
@@ -28,7 +28,7 @@ include('admin-header.php');
 </td>
 </tr>
 <tr valign="top">
-<th scope="row"><?php _e('Default post category:') ?></th>
+<th scope="row"><?php _e('Default Post Category') ?></th>
 <td><select name="default_category" id="default_category">
 <?php
 $categories = get_categories('get=all');
@@ -42,7 +42,7 @@ endforeach;
 </select></td>
 </tr>
 <tr valign="top">
-<th scope="row"><?php _e('Default link category:') ?></th>
+<th scope="row"><?php _e('Default Link Category') ?></th>
 <td><select name="default_link_category" id="default_link_category">
 <?php
 $link_categories = get_terms('link_category', 'get=all');
@@ -56,10 +56,11 @@ endforeach;
 </select></td>
 </tr>
 </table>
+
+
 <p class="submit">
 <input type="hidden" name="action" value="update" />
-<input type="hidden" name="page_options" value="default_post_edit_rows,use_smilies,default_category,default_email_category,use_balanceTags,default_link_category" /> 
-<input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" />
+<input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
 </p>
 </form>
 </div>
