@@ -3,11 +3,12 @@ require_once('admin.php');
 
 $title = __('WordPress MU &rsaquo; Admin &rsaquo; Blogs');
 $parent_file = 'wpmu-admin.php';
-wp_enqueue_script( 'listman' );
-require_once('admin-header.php');
 
+wp_enqueue_script( 'admin-forms' );
+
+require_once('admin-header.php');
 if( is_site_admin() == false ) {
-    wp_die( __('<p>You do not have permission to access this page.</p>') );
+    wp_die( __('You do not have permission to access this page.') );
 }
 $id = intval( $_GET['id'] );
 
@@ -16,6 +17,9 @@ if ( $_GET['updated'] == 'true' ) {
 	<div id="message" class="updated fade"><p>
 		<?php
 		switch ($_GET['action']) {
+			case 'all_notspam':
+				_e('Blogs mark as not spam !');
+			break;
 			case 'all_spam':
 				_e('Blogs mark as spam !');
 			break;
@@ -69,8 +73,7 @@ switch( $_GET['action'] ) {
 		$editblog_roles = get_blog_option( $id, "{$wpdb->base_prefix}{$id}_user_roles" );
 		?>
 		<div class="wrap">
-		<h2><?php _e('Edit Blog'); ?></h2>
-		<a href='http://<?php echo $details['domain'].$details['path']; ?>'><?php echo $details['domain'].$details['path']; ?></a>
+		<h2><?php _e('Edit Blog'); ?> - <a href='http://<?php echo $details['domain'].$details['path']; ?>'><?php echo $details['domain'].$details['path']; ?></a></h2>		
 		<form method="post" action="wpmu-edit.php?action=updateblog"> 
 			<?php wp_nonce_field('editblog'); ?>
 			<input type="hidden" name="id" value="<?php echo $id ?>" /> 
@@ -78,61 +81,64 @@ switch( $_GET['action'] ) {
 			<tr>
 				<td valign="top">
 					<div class="wrap">
-						<table style="border:0; width:100%;" cellspacing="2" cellpadding="5" class="editform"> 
-							<tr valign="top"> 
-								<th scope="row"><?php _e('URL') ?></th> 
-								<td>http://<input name="blog[domain]" type="text" id="domain" value="<?php echo $details['domain'] ?>" size="33" /></td> 
+						<h3><?php _e('Blog info (wp_blogs)'); ?></h3>
+						<table class="form-table">
+							<tr class="form-field form-required">
+								<th scope="row"><?php _e('Domain') ?></th> 
+								<td>http://<input name="blog[domain]" type="text" id="domain" value="<?php echo $details['domain'] ?>" size="33" /></td>
 							</tr> 
-							<tr valign="top"> 
+							<tr class="form-field form-required">
 								<th scope="row"><?php _e('Path') ?></th> 
-								<td><input name="blog[path]" type="text" id="path" value="<?php echo $details['path'] ?>" size="40" /></td> 
+								<td><input name="blog[path]" type="text" id="path" value="<?php echo $details['path'] ?>" size="40" />
+								<br />(<?php _e( 'siteurl and home will be modified too' ); ?>)</td> 
 							</tr> 
-							<tr valign="top"> 
+							<tr class="form-field">
 								<th scope="row"><?php _e('Registered') ?></th> 
 								<td><input name="blog[registered]" type="text" id="blog_registered" value="<?php echo $details['registered'] ?>" size="40" /></td> 
 							</tr> 
-							<tr valign="top"> 
+							<tr class="form-field">
 								<th scope="row"><?php _e('Last Updated') ?></th> 
 								<td><input name="blog[last_updated]" type="text" id="blog_last_updated" value="<?php echo $details['last_updated'] ?>" size="40" /></td> 
 							</tr> 
-							<tr valign="top"> 
+							<tr class="form-field">
 								<th scope="row"><?php _e('Public') ?></th> 
 								<td>
 									<input type='radio' name='blog[public]' value='1' <?php if( $details['public'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
 									<input type='radio' name='blog[public]' value='0' <?php if( $details['public'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
 								</td> 
 							</tr> 
-							<tr valign="top"> 
+							<tr class="form-field">
 								<th scope="row"><?php _e( 'Archived' ); ?></th> 
 								<td>
 									<input type='radio' name='blog[archived]' value='1' <?php if( $details['archived'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
 									<input type='radio' name='blog[archived]' value='0' <?php if( $details['archived'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
 								</td> 
 							</tr> 
-							<tr valign="top"> 
+							<tr class="form-field">
 								<th scope="row"><?php _e( 'Mature' ); ?></th> 
 								<td>
 									<input type='radio' name='blog[mature]' value='1' <?php if( $details['mature'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
 									<input type='radio' name='blog[mature]' value='0' <?php if( $details['mature'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
 								</td> 
 							</tr> 
-							<tr valign="top"> 
+							<tr class="form-field">
 								<th scope="row"><?php _e( 'Spam' ); ?></th> 
 								<td>
 									<input type='radio' name='blog[spam]' value='1' <?php if( $details['spam'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
 									<input type='radio' name='blog[spam]' value='0' <?php if( $details['spam'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
 								</td> 
 							</tr> 
-							<tr valign="top"> 
+							<tr class="form-field">
 								<th scope="row"><?php _e( 'Deleted' ); ?></th> 
 								<td>
 									<input type='radio' name='blog[deleted]' value='1' <?php if( $details['deleted'] == '1' ) echo 'checked="checked"'; ?> /> <?php _e('Yes') ?>
 									<input type='radio' name='blog[deleted]' value='0' <?php if( $details['deleted'] == '0' ) echo 'checked="checked"'; ?> /> <?php _e('No') ?>
 								</td> 
 							</tr> 
-							<tr>
-								<td colspan="2"><br /><br /></td>
-							</tr>
+						</table>
+						
+						<h3><?php printf( __('Blog options (wp_%s_options)'), $id ); ?></h3>
+						<table class="form-table">
 							<?php
 							$editblog_default_role = 'subscriber';
 							foreach ( $options as $key => $val ) {
@@ -150,14 +156,14 @@ switch( $_GET['action'] ) {
 								}
 								if ( stristr($val['option_value'], "\r") || stristr($val['option_value'], "\n") || stristr($val['option_value'], "\r\n") ) {
 								?>
-									<tr valign="top"> 
+									<tr class="form-field">
 										<th scope="row"><?php echo ucwords( str_replace( "_", " ", $val['option_name'] ) ) ?></th> 
 										<td><textarea rows="5" cols="40" name="option[<?php echo $val['option_name'] ?>]" type="text" id="<?php echo $val['option_name'] ?>"<?php echo $disabled ?>><?php echo wp_specialchars( stripslashes( $val['option_value'] ), 1 ) ?></textarea></td>
 									</tr>
 								<?php
 								} else {
 								?>
-									<tr valign="top"> 
+									<tr class="form-field">
 										<th scope="row"><?php echo ucwords( str_replace( "_", " ", $val['option_name'] ) ) ?></th> 
 										<td><input name="option[<?php echo $val['option_name'] ?>]" type="text" id="<?php echo $val['option_name'] ?>" value="<?php echo wp_specialchars( stripslashes( $val['option_value'] ), 1 ) ?>" size="40" <?php echo $disabled ?> /></td> 
 									</tr> 
@@ -167,7 +173,7 @@ switch( $_GET['action'] ) {
 							?>
 						</table>
 						<p class="submit">
-						<input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>
+							<input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>
 					</div>
 				</td>
 				<td valign="top">
@@ -184,27 +190,28 @@ switch( $_GET['action'] ) {
 						$theme_key = wp_specialchars( $theme['Stylesheet'] );
 						if( isset($allowed_themes[$theme_key] ) == false ) {
 							$checked = ( isset($blog_allowed_themes[ $theme_key ]) ) ? 'checked="checked"' : '';							
-							$out .= '<tr valign="top"> 
+							$out .= '<tr class="form-field form-required"> 
 									<th title="'.htmlspecialchars( $theme["Description"] ).'" scope="row">'.$key.'</th> 
 									<td><input name="theme['.$theme_key.']" type="checkbox" value="on" '.$checked.'/></td> 
 								</tr>';
 						}
 					}
 					
+							
 					if( $out != '' ) {
-						echo "<div class='wrap'><h3>" . __('Blog Themes') . "</h3>";
-						echo '<table width="100%" border="0" cellspacing="2" cellpadding="5" class="editform">';
-						echo '<tr><th>' . __('Theme') . '</th><th>' . __('Enable') . '</th></tr>';
-						echo $out;
-						echo "</table></div>";
+						echo "<h3>" . __('Blog Themes') . "</h3>";
+						echo '<table class="form-table">';						
+							echo '<tr class=""><th>' . __('Theme') . '</th><th>' . __('Enable') . '</th></tr>';
+							echo $out;
+						echo "</table>";
 					}
 					
 					// Blog users
 					$blogusers = get_users_of_blog( $id );
-					echo '<div class="wrap"><h3>' . __('Blog Users') . '</h3>';
+					echo '<h3>' . __('Blog Users') . '</h3>';
 					if( is_array( $blogusers ) ) {
-						echo '<table width="100%"><caption>' . __('Current Users') . '</caption>';
-						echo "<tr><th>" . __('User') . "</th><th>" . __('Role') . "</th><th>" . __('Password') . "</th><th>" . __('Remove') . "</th><th></th></tr>";
+						echo '<table class="form-table">';
+						echo "<tr><th>" . __('User') . "</th><th>" . __('Role') . "</th><th>" . __('Password') . "</th><th>" . __('Remove') . "</th></tr>";
 						reset($blogusers);
 						foreach ( (array) $blogusers as $key => $val ) {
 							$t = @unserialize( $val->meta_value );
@@ -212,14 +219,15 @@ switch( $_GET['action'] ) {
 								reset( $t );
 								$existing_role = key( $t );
 							}
-							echo "<tr><td>" . $val->user_login . "</td>";
+							echo '<tr><td><a href="user-edit.php?user_id=' . $val->user_id . '">' . $val->user_login . '</a></td>';
 							if( $val->user_id != $current_user->data->ID ) {
 								?>
 								<td>
 									<select name="role[<?php echo $val->user_id ?>]" id="new_role"><?php 
 										foreach( $editblog_roles as $role => $role_assoc ){
+											$name = translate_with_context($role_assoc['name']);
 											$selected = ( $role == $existing_role ) ? 'selected="selected"' : '';
-											echo "<option {$selected} value=\"{$role}\">{$role_assoc['name']}</option>";
+											echo "<option {$selected} value=\"{$role}\">{$name}</option>";
 										}
 										?>
 									</select>
@@ -232,16 +240,15 @@ switch( $_GET['action'] ) {
 							} else {
 								echo "<td><strong>" . __ ('N/A') . "</strong></td><td><strong>" . __ ('N/A') . "</strong></td><td><strong>" . __('N/A') . "</strong></td>";
 							}
-							echo '<td><a href="user-edit.php?user_id=' . $val->user_id . '">' . __('Edit') . "</a></td></tr>";
+							echo '</tr>';
 						}
 						echo "</table>";
 					}
 					
 					// New blog user
-					echo "<h3>" . __('Add a new user') . "</h3>";
-					?>
+					echo "<h3>" . __('Add a new user') . "</h3>"; ?>
 					<p><?php _e('As you type WordPress will offer you a choice of usernames.<br /> Click them to select and hit <em>Update Options</em> to add the user.') ?></p>
-					<table>
+					<table class="form-table">
 						<tr>
 							<th scope="row"><?php _e('User&nbsp;Login:') ?></th>
 							<td><input type="text" name="newuser" id="newuser" /></td>
@@ -253,20 +260,20 @@ switch( $_GET['action'] ) {
 								<?php 
 								reset( $editblog_roles );
 								foreach( $editblog_roles as $role => $role_assoc ){
+									$name = translate_with_context($role_assoc['name']);
 									$selected = ( $role == $editblog_default_role ) ? 'selected="selected"' : '';
-									echo "<option {$selected} value=\"{$role}\">{$role_assoc['name']}</option>";
+									echo "<option {$selected} value=\"{$role}\">{$name}</option>";
 								}
 								?>
 								</select>
 							</td>
 						</tr>
 					</table>
-					</div>
 					
-					<div class="wrap">
-						<strong><?php _e('Misc Blog Actions') ?></strong>
-						<p><?php do_action( 'wpmueditblogaction', $id ); ?></p>
-					</div>
+					<h3><?php _e('Misc Blog Actions') ?></h3>
+					<table class="form-table">
+						<?php do_action( 'wpmueditblogaction', $id ); ?>
+					</table>
 					
 					<p class="submit">
 						<input type="submit" name="Submit" value="<?php _e('Update Options &raquo;') ?>" /></p>				
@@ -280,34 +287,35 @@ switch( $_GET['action'] ) {
 	
 	// List blogs
 	default:
-		$start = isset( $_GET['start'] ) ? intval( $_GET['start'] ) : 0;
-		$num = isset( $_GET['num'] ) ? intval( $_GET['num'] ) : 60;
+		$apage = isset( $_GET['apage'] ) ? intval( $_GET['apage'] ) : 1;
+		$num = isset( $_GET['num'] ) ? intval( $_GET['num'] ) : 15;
 		
 		$query = "SELECT * FROM {$wpdb->blogs} WHERE site_id = '{$wpdb->siteid}' ";
 		
-		if( !empty($_GET['s']) ) {
+		if( isset($_GET['blog_name']) ) {
 			$s = trim($_GET['s']);
 			$query = "SELECT blog_id, {$wpdb->blogs}.domain, {$wpdb->blogs}.path, registered, last_updated
 				FROM {$wpdb->blogs}, {$wpdb->site}
 				WHERE site_id = '{$wpdb->siteid}'
 				AND {$wpdb->blogs}.site_id = {$wpdb->site}.id
 				AND ( {$wpdb->blogs}.domain LIKE '%{$s}%' OR {$wpdb->blogs}.path LIKE '%{$s}%' )";
-		} elseif( !empty($_GET['blog_id']) ) {
+		} elseif( isset($_GET['blog_id']) ) {
 			$query = "SELECT * 
 				FROM {$wpdb->blogs}
 				WHERE site_id = '{$wpdb->siteid}'
-				AND   blog_id = '".intval($_GET['blog_id'])."'";
-		} elseif( !empty($_GET['ip_address']) ) {
+				AND   blog_id = '".intval($_GET['s'])."'";
+		} elseif( isset($_GET['blog_ip']) ) {
 			$query = "SELECT *
 				FROM {$wpdb->blogs}, {$wpdb->registration_log}
 				WHERE site_id = '{$wpdb->siteid}'
 				AND {$wpdb->blogs}.blog_id = {$wpdb->registration_log}.blog_id
-				AND {$wpdb->registration_log}.IP LIKE ('%".$_GET['ip_address']."%')";
+				AND {$wpdb->registration_log}.IP LIKE ('%".$_GET['s']."%')";
 		}
 		
 		if( isset( $_GET['sortby'] ) == false ) {
 			$_GET['sortby'] = 'id';
 		}
+		
 		if( $_GET['sortby'] == 'registered' ) {
 			$query .= ' ORDER BY registered ';
 		} elseif( $_GET['sortby'] == 'id' ) {
@@ -320,107 +328,72 @@ switch( $_GET['action'] ) {
 
 		$query .= ( $_GET['order'] == 'DESC' ) ? 'DESC' : 'ASC';
 		
-		if ( $_GET['ip_address'] == '' )
-			$query .= " LIMIT " . intval( $start ) . ", " . intval( $num );
+		if( !empty($_GET['s']) ) {
+			$blog_list = $wpdb->get_results( $query, ARRAY_A );	
+			$total = count($blog_list);	
+		} else {
+			$total = $wpdb->get_var( "SELECT COUNT(*) FROM {$wpdb->blogs} WHERE site_id = '{$wpdb->siteid}' ");	
+		}
+		
+		$query .= " LIMIT " . intval( ( $apage - 1 ) * $num) . ", " . intval( $num );
 			
 		$blog_list = $wpdb->get_results( $query, ARRAY_A );	
-		
-		$next = ( count( $blog_list ) < $num ) ? false : true;
-		
-		// Pagination
-		$url2 = "order=" . $_GET['order'] . "&amp;sortby=" . $_GET['sortby'] . "&amp;s=" . $_GET['s'] . "&ip_address=" . $_GET['ip_address'];
-		$blog_navigation = '';
-		if( $start == 0 ) { 
-			$blog_navigation .= __('Previous&nbsp;Blogs');
-		} elseif( $start <= 30 ) { 
-			$blog_navigation .= '<a href="wpmu-blogs.php?start=0&amp;' . $url2 . ' ">' . __('Previous&nbsp;Blogs') . '</a>';
-		} else {
-			$blog_navigation .= '<a href="wpmu-blogs.php?start=' . ( $start - $num ) . '&' . $url2 . '">' . __('Previous&nbsp;Blogs') . '</a>';
-		} 
-		if ( $next ) {
-			$blog_navigation .= '&nbsp;||&nbsp;<a href="wpmu-blogs.php?start=' . ( $start + $num ) . '&' . $url2 . '">' . __('Next&nbsp;Blogs') . '</a>';
-		} else {
-			$blog_navigation .= '&nbsp;||&nbsp;' . __('Next&nbsp;Blogs');
-		}
-		?>
-		<script type="text/javascript">
-		<!--
-		var checkflag = "false";
-		
-		function check_all_rows() {
-			var button1 = document.getElementById('check_all1'); 
-			var button2 = document.getElementById('check_all2');
-	  
-			field = document.formlist;
-			if (checkflag == "false") {
-				for (i = 0; i < field.length; i++) {
-					if( field[i].name == 'allblogs[]' ) {
-						field[i].checked = true;
-					}
-				}
-				checkflag = "true";
-				button1.value = "<?php _e('Uncheck All') ?>";
-				button2.value = "<?php _e('Uncheck All') ?>";
-			} else {
-				for (i = 0; i < field.length; i++) {
-					if( field[i].name == 'allblogs[]' ) {
-						field[i].checked = false;
-					}
-				}
-				checkflag = "false";
-				button1.value = "<?php _e('Check All') ?>"; 
-				button2.value = "<?php _e('Check All') ?>"
-			}
-		}		
-		//  -->
-		</script>
-		<div class="wrap">
-		<h2><?php _e('Blogs') ?></h2>
-		<div style="float:right; padding:0 20px; margin-top:20px;"> 
-			<h4 style="margin:0 0 4px;"><?php _e('Blog Navigation') ?></h4> 
-			<?php echo $blog_navigation; ?>
-		</div>
-		
-		<form id="searchform" action="wpmu-blogs.php" method="get"> 
-			<input type="hidden" name="action" value="blogs" />
-			<fieldset>
-				<legend><?php _e('Search blogs by name&hellip;') ?></legend> 
-				<input type="text" name="s" value="<?php if (isset($_GET['s'])) echo stripslashes(wp_specialchars($_GET['s'], 1)); ?>" size="17" />
-			</fieldset>
-			
-			<fieldset>
-				<legend><?php _e('by blog ID&hellip;') ?></legend> 
-				<input type="text" name="blog_id" value="<?php if (isset($_GET['blog_id'])) echo wp_specialchars($_GET['blog_id'], 1); ?>" size="10" />
-			</fieldset>
-			
-			<fieldset>
-				<legend><?php _e('by IP address&hellip;') ?></legend> 
-				<input type="text" name="ip_address" value="<?php if (isset($_GET['ip_address'])) echo wp_specialchars($_GET['ip_address'], 1); ?>" size="10" />
-			</fieldset>			
-			<input type="submit" name="submit" id="post-query-submit" value="<?php _e('Search') ?>" class="button" /> 
-		</form>
 
+		// Pagination
+		$url2 = "&order=" . $_GET['order'] . "&amp;sortby=" . $_GET['sortby'] . "&amp;s=" . $_GET['s'] . "&ip_address=" . $_GET['ip_address'];
+		$blog_navigation = paginate_links( array(
+			'base' => add_query_arg( 'apage', '%#%' ).$url2,
+			'format' => '',
+			'total' => ceil($total / $num),
+			'current' => $apage
+		));
+		?>
+
+		<div class="wrap" style="position:relative;">
+		<h2><?php _e('Blogs') ?></h2>
 		
-		<br style="clear:both;" />	
+		<form id="searchform" action="wpmu-blogs.php" method="get" style="position:absolute;right:0;top:0;">
+			<input type="hidden" name="action" value="blogs" />			
+			<input type="text" name="s" value="<?php if (isset($_GET['s'])) echo stripslashes(wp_specialchars($_GET['s'], 1)); ?>" size="17" />
+			<input type="submit" class="button" name="blog_name" value="<?php _e('Search blogs by name') ?>" />
+			<input type="submit" class="button" name="blog_id" value="<?php _e('by blog ID') ?>" />		
+			<input type="submit" class="button" name="blog_ip" value="<?php _e('by IP address') ?>" />		
+		</form>
+	
+		<form id="form-blog-list" action="wpmu-edit.php?action=allblogs" method="post">
+		
+		<div class="tablenav">
+			<?php if ( $blog_navigation ) echo "<div class='tablenav-pages'>$blog_navigation</div>"; ?>	
+
+			<div class="alignleft">
+				<input type="submit" value="<?php _e('Delete') ?>" name="allblog_delete" class="button-secondary delete" />
+				<input type="submit" value="<?php _e('Mark as Spam') ?>" name="allblog_spam" class="button-secondary" />
+				<input type="submit" value="<?php _e('Not Spam') ?>" name="allblog_notspam" class="button-secondary" />
+				<?php wp_nonce_field( 'allblogs' ); ?>
+				<br class="clear" />
+			</div>
+		</div>
+
+		<br class="clear" />
 		
 		<?php if( isset($_GET['s']) && !empty($_GET['s']) ) : ?>
 			<p><a href="wpmu-users.php?action=users&s=<?php echo stripslashes(wp_specialchars($_GET['s'], 1)) ?>"><?php _e('Search Users:') ?> <strong><?php echo stripslashes(wp_specialchars($_GET['s'], 1)); ?></strong></a></p>
-		<?php endif; ?>				
-	
+		<?php endif; ?>		
+
 		<?php
 		// define the columns to display, the syntax is 'internal name' => 'display name'
+		$blogname_columns = ( constant( "VHOST" ) == 'yes' ) ? __('Domain') : __('Path');
 		$posts_columns = array(
-		'id'           => __('ID'),
-		'blogname'     => __('Blog Name'),
-		'lastupdated'  => __('Last Updated'),
-		'registered'   => __('Registered'),
-		'users'        => __('Users'),
-		'plugins'      => __('Actions')
+			'id'           => __('ID'),
+			'blogname'     => $blogname_columns,
+			'lastupdated'  => __('Last Updated'),
+			'registered'   => __('Registered'),
+			'users'        => __('Users'),
+			'plugins'      => __('Actions')
 		);
 		$posts_columns = apply_filters('manage_posts_columns', $posts_columns);
 
 		// you can not edit these at the moment
-		$posts_columns['control_view'] 		= '';
 		$posts_columns['control_edit']      = '';
 		$posts_columns['control_backend']   = '';
 		$posts_columns['control_deactivate']= '';
@@ -430,21 +403,28 @@ switch( $_GET['action'] ) {
 
 		$sortby_url = "s=" . $_GET['s'] . "&amp;ip_address=" . $_GET['ip_address'];
 		?>
-		<form name="formlist" action="wpmu-edit.php?action=allblogs" method="post">
-		<input style="margin:5px 0;" id="check_all1" class="button" type="button" value="<?php _e('Check All') ?>" onclick="check_all_rows()" /> 
 		
 		<table width="100%" cellpadding="3" cellspacing="3" class="widefat">
 			<thead>
 				<tr>
-					<?php foreach($posts_columns as $column_id => $column_display_name) : ?>
-						<th scope="col"><a href="wpmu-blogs.php?<?php echo $sortby_url ?>&amp;sortby=<?php echo $column_id ?>&amp;<?php if( $_GET['sortby'] == $column_id ) { if( $_GET['order'] == 'DESC' ) { echo "order=ASC&amp;" ; } else { echo "order=DESC&amp;"; } } ?>start=<?php echo $start ?>"><?php echo $column_display_name; ?></a></th>
-					<?php endforeach ?>
+				<th scope="col" class="check-column"><input type="checkbox" onclick="checkAll(document.getElementById('form-blog-list'));" /></th>
+				<?php foreach($posts_columns as $column_id => $column_display_name) {
+					$column_link = "<a href='wpmu-blogs.php?{$sortby_url}&amp;sortby={$column_id}&amp;";
+					if( $_GET['sortby'] == $column_id ) { 
+						$column_link .= $_GET[ 'order' ] == 'DESC' ? 'order=ASC&amp;' : 'order=DESC&amp;';
+					}
+					$column_link .= "apage={$apage}'>{$column_display_name}</a>";
+					
+					$col_url = ($column_id == 'users' || $column_id == 'plugins') ? $column_display_name : $column_link;
+					?>
+					<th scope="col"><?php echo $col_url ?></th>
+				<?php } ?>
 				</tr>
 			</thead>
 			<tbody id="the-list">
 			<?php
 			if ($blog_list) {
-				$bgcolor = '';
+				$bgcolor = $class = '';
 				$status_list = array( "archived" => "#fee", "spam" => "#faa", "deleted" => "#f55" );
 				foreach ($blog_list as $blog) { 
 					$class = ('alternate' == $class) ? '' : 'alternate';
@@ -462,15 +442,18 @@ switch( $_GET['action'] ) {
 					foreach( $posts_columns as $column_name=>$column_display_name ) {
 						switch($column_name) {
 							case 'id': ?>
+								<th scope="row" class="check-column">
+									<input type='checkbox' id='blog_<?php echo $blog['blog_id'] ?>' name='allblogs[]' value='<?php echo $blog['blog_id'] ?>' />
+								</th>
 								<th scope="row">
-									<input type='checkbox' id='blog_<?php echo $blog['blog_id'] ?>' name='allblogs[]' value='<?php echo $blog['blog_id'] ?>' /> <label for='blog_<?php echo $blog['blog_id'] ?>'><?php echo $blog['blog_id'] ?></label>
+									<?php echo $blog['blog_id'] ?>
 								</th>
 							<?php
 							break;
  
 							case 'blogname': ?>
 								<td valign="top">
-									<label for='blog_<?php echo $blog['blog_id'] ?>'><?php echo $blogname ?></label>
+									<a href="http://<?php echo $blog['domain']. $blog['path']; ?>" rel="permalink"><?php echo $blogname; ?></a>
 								</td>
 							<?php
 							break;
@@ -504,12 +487,6 @@ switch( $_GET['action'] ) {
 								</td>
 							<?php
 							break;
-							case 'control_view': ?>
-								<td valign="top">
-									<a href="http://<?php echo $blog['domain']. $blog['path']; ?>" rel="permalink" class="edit"><?php _e('View'); ?></a>
-								</td>
-							<?php
-							break;
 							case 'control_edit': ?>
 								<td valign="top">
 									<?php echo "<a href='wpmu-blogs.php?action=editblog&amp;id=".$blog['blog_id']."' class='edit'>" . __('Edit') . "</a>"; ?>
@@ -527,11 +504,11 @@ switch( $_GET['action'] ) {
 							case 'control_spam': 
 								if( get_blog_status( $blog['blog_id'], "spam" ) == '1' ) { ?>
 									<td valign="top">
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=unspamblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to unspam the blog %s" ), $blogname ) ) ?>" onclick="return deleteSomething( 'blog', <?php echo $blog['blog_id']; ?>, '<?php echo js_escape(sprintf(__("You are about to mark as not spam this blog '%s'.\n'OK' to delete, 'Cancel' to stop."), $blogname)); ?>' );"><?php _e("Not Spam") ?></a>
+										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=unspamblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to unspam the blog %s" ), $blogname ) ) ?>"><?php _e("Not Spam") ?></a>
 									</td>
 								<?php } else { ?>
 									<td valign='top'>
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=spamblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to mark the blog %s as spam" ), $blogname ) ) ?>" onclick="return deleteSomething( 'blog', <?php echo $blog['blog_id']; ?>, '<?php echo js_escape(sprintf(__("You are about to mark as spam this blog '%s'.\n'OK' to delete, 'Cancel' to stop."), $blogname)); ?>' );"><?php _e("Spam") ?></a>
+										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=spamblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to mark the blog %s as spam" ), $blogname ) ) ?>""><?php _e("Spam") ?></a>
 									</td>
 								<?php }
 							break;
@@ -539,11 +516,11 @@ switch( $_GET['action'] ) {
 							case 'control_deactivate':
 								if( get_blog_status( $blog['blog_id'], "deleted" ) == '1' ) { ?>
 									<td valign="top">
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=activateblog&amp;ref=<?php echo urlencode( $_SERVER['REQUEST_URI'] ) ?>&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to activate the blog %s" ), $blogname ) ) ?>" onclick="return deleteSomething( 'blog', <?php echo $blog['blog_id']; ?>, '<?php echo js_escape(sprintf(__("You are about to activate this blog '%s'.\n'OK' to delete, 'Cancel' to stop."), $blogname)); ?>' );"><?php _e("Activate") ?></a>
+										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=activateblog&amp;ref=<?php echo urlencode( $_SERVER['REQUEST_URI'] ) ?>&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to activate the blog %s" ), $blogname ) ) ?>"><?php _e("Activate") ?></a>
 									</td>
 								<?php } else { ?>
 									<td valign="top">
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=deactivateblog&amp;ref=<?php echo urlencode( $_SERVER['REQUEST_URI'] ) ?>&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to deactivate the blog %s" ), $blogname ) ) ?>" onclick="return deleteSomething( 'blog', <?php echo $blog['blog_id']; ?>, '<?php echo js_escape(sprintf(__("You are about to deactive this blog '%s'.\n'OK' to delete, 'Cancel' to stop."), $blogname)); ?>' );"><?php _e("Deactivate") ?></a>
+										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=deactivateblog&amp;ref=<?php echo urlencode( $_SERVER['REQUEST_URI'] ) ?>&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to deactivate the blog %s" ), $blogname ) ) ?>"><?php _e("Deactivate") ?></a>
 									</td>
 								<?php }
 							break;
@@ -551,18 +528,18 @@ switch( $_GET['action'] ) {
 							case 'control_archive':
 								if( get_blog_status( $blog['blog_id'], "archived" ) == '1' ) { ?>
 									<td valign="top">
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=unarchiveblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to unarchive the blog %s" ), $blogname ) ) ?>" onclick="return deleteSomething( 'blog', <?php echo $blog['blog_id']; ?>, '<?php echo js_escape(sprintf(__("You are about to unarchive this blog '%s'.\n'OK' to delete, 'Cancel' to stop."), $blogname)); ?>' );"><?php _e("Unarchive") ?></a>
+										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=unarchiveblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to unarchive the blog %s" ), $blogname ) ) ?>"><?php _e("Unarchive") ?></a>
 									</td>
 								<?php } else { ?>
 									<td valign="top">
-										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=archiveblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to archive the blog %s" ), $blogname ) ) ?>" onclick="return deleteSomething( 'blog', <?php echo $blog['blog_id']; ?>, '<?php echo js_escape(sprintf(__("You are about to archive this blog '%s'.\n'OK' to delete, 'Cancel' to stop."), $blogname)); ?>' );"><?php _e("Archive") ?></a>
+										<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=archiveblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to archive the blog %s" ), $blogname ) ) ?>"><?php _e("Archive") ?></a>
 									</td>
 								<?php }
 							break;
 
 							case 'control_delete': ?>
 								<td valign="top">
-									<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=deleteblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to delete the blog %s" ), $blogname ) ) ?>" onclick="return deleteSomething( 'blog', <?php echo $blog['blog_id']; ?>, '<?php echo js_escape(sprintf(__("You are about to delete this blog '%s'.\n'OK' to delete, 'Cancel' to stop."), $blogname)); ?>' );"><?php _e("Delete") ?></a>
+									<a class='delete' href="wpmu-edit.php?action=confirm&amp;action2=deleteblog&amp;id=<?php echo $blog['blog_id'] ?>&amp;msg=<?php echo urlencode( sprintf( __( "You are about to delete the blog %s" ), $blogname ) ) ?>"><?php _e("Delete") ?></a>
 								</td>
 							<?php break;
 
@@ -593,32 +570,15 @@ switch( $_GET['action'] ) {
 
 			</tbody>
 		</table>
-		
-		<div style="float:right; padding:0 20px; margin-top:20px;"> 
-			<h4 style="margin:0 0 4px;"><?php _e('Blog Navigation') ?></h4> 
-			<?php echo $blog_navigation;?>
-		</div>
-		<input style="margin:5px 0;" id="check_all2" type="button" class="button" value="<?php _e('Check All') ?>" onclick="check_all_rows()" /> 
-		
-		<h3><?php _e('Update selected blogs:') ?></h3>
-		<ul style="list-style:none;">
-			<li><input type='radio' name='blogfunction' id='delete' value='delete' /> <label for='delete'><?php _e('Delete') ?></label></li>
-			<li><input type='radio' name='blogfunction' id='spam' value='spam' /> <label for='spam'><?php _e('Mark as Spam') ?></label></li>
-		</ul>
-		
-		<p class="submit" style="width: 220px">
-			<?php wp_nonce_field( "allblogs" ); ?>
-			<input type='hidden' name='redirect' value='<?php echo $_SERVER['REQUEST_URI'] ?>' />
-			<input type='submit' class="button" value='<?php _e('Apply Changes') ?>' /></p>
-		</form>
+		</form>		
 		</div>
 		
 		<div class="wrap">
 			<h2><?php _e('Add Blog') ?></h2>
 			<form method="post" action="wpmu-edit.php?action=addblog">
 				<?php wp_nonce_field('add-blog') ?>
-				<table cellpadding="3" cellspacing="3">
-					<tr>
+				<table class="form-table">
+					<tr class="form-field form-required">	
 						<th style="text-align:center;" scope='row'><?php _e('Blog Address') ?></th>
 						<td>
 						<?php if( constant( "VHOST" ) == 'yes' ) : ?>
@@ -628,12 +588,20 @@ switch( $_GET['action'] ) {
 						<?php endif; ?>
 						</td>
 					</tr>
-					<tr><th style="text-align:center;" scope='row'><?php _e('Blog Title') ?></th><td><input name="blog[title]" type="text" size="20" title="<?php _e('Title') ?>"/></td></tr>
-					<tr><th style="text-align:center;" scope='row'><?php _e('Admin Email') ?></th><td><input name="blog[email]" type="text" size="20" title="<?php _e('Email') ?>"/></td></tr>
-					<tr><td colspan='2'><?php _e('A new user will be created if the above email address is not in the database.') ?></td></tr>
-					<tr><td colspan='2'><?php _e('The username and password will be mailed to this email address.') ?></td></tr>
+					<tr class="form-field form-required">
+						<th style="text-align:center;" scope='row'><?php _e('Blog Title') ?></th>
+						<td><input name="blog[title]" type="text" size="20" title="<?php _e('Title') ?>"/></td>
+					</tr>
+					<tr class="form-field form-required">	
+						<th style="text-align:center;" scope='row'><?php _e('Admin Email') ?></th>
+						<td><input name="blog[email]" type="text" size="20" title="<?php _e('Email') ?>"/></td>
+					</tr>
+					<tr class="form-field">
+						<td colspan='2'><?php _e('A new user will be created if the above email address is not in the database.') ?><br /><?php _e('The username and password will be mailed to this email address.') ?></td>
+					</tr>
 				</table>
-				<input class="button" type="submit" name="go" value="<?php _e('Add Blog') ?>" />
+				<p class="submit">
+					<input class="button" type="submit" name="go" value="<?php _e('Add Blog') ?>" /></p>
 			</form>
 		</div>
 		<?php
