@@ -10,6 +10,12 @@ define('DB_COLLATE', '');
 define('VHOST', 'VHOSTSETTING'); 
 $base = 'BASE';
 
+// Change SECRET_KEY to a unique phrase.  You won't have to remember it later,
+// so make it long and complicated.  You can visit http://api.wordpress.org/secret-key/1.0/
+// to get a secret key generated for you, or just make something up.
+define('SECRET_KEY', 'put your unique phrase here'); // Change this to a unique phrase.
+define('SECRET_SALT', 'put your unique phrase here'); // Change this to a unique phrase.
+
 // double check $base
 if( $base == 'BASE' )
 	die( 'Problem in wp-config.php - $base is set to BASE when it should be the path like "/" or "/blogs/"! Please fix it!' );
@@ -21,9 +27,14 @@ $table_prefix  = 'wp_';   // Only numbers, letters, and underscores please!
 // For example, install de.mo to wp-content/languages and set WPLANG to 'de'
 // to enable German language support.
 define ('WPLANG', '');
+
 // uncomment this to enable wp-content/sunrise.php support
 //define( 'SUNRISE', 'on' );
 
+// Uncomment and set this to a URL to redirect if a blog does not exist. (Useful if signup is disabled)
+// Browser will redirect to constant( 'NOBLOGREDICT' ) . "?new=blogname" where blogname is the unknown blog
+// define( 'NOBLOGREDIRECT', '' );
+
 define( "WP_USE_MULTIPLE_DB", false );
 
 /* That's all, stop editing! Happy blogging. */
