@@ -19,6 +19,8 @@ function wpmu_update_blogs_date() {
 
 	$wpdb->query( "UPDATE {$wpdb->blogs} SET last_updated = NOW() WHERE  blog_id = '{$wpdb->blogid}'" );
 	refresh_blog_details( $wpdb->blogid );
+
+	do_action( 'wpmu_blog_updated', $wpdb->blogid );
 }
 
 add_action('delete_post', 'wpmu_update_blogs_date');
@@ -28,7 +30,7 @@ add_action('publish_post', 'wpmu_update_blogs_date');
 
 function get_blogaddress_by_id( $blog_id ) {
 	$bloginfo = get_blog_details( (int) $blog_id, false ); // only get bare details!
-	return "http://" . $bloginfo->domain . $bloginfo->path;
+	return clean_url("http://" . $bloginfo->domain . $bloginfo->path);
 }
 
 function get_blogaddress_by_name( $blogname ) {
@@ -37,9 +39,9 @@ function get_blogaddress_by_name( $blogname ) {
 	if( defined( "VHOST" ) && constant( "VHOST" ) == 'yes' ) {
 		if( $blogname == 'main' )
 			$blogname = 'www';
-		return "http://".$blogname.".".$domain.$base;
+		return clean_url("http://".$blogname.".".$domain.$base);
 	} else {
-		return "http://".$hostname.$base.$blogname;
+		return clean_url("http://".$hostname.$base.$blogname);
 	}
 }
 
@@ -58,7 +60,7 @@ function get_blogaddress_by_domain( $domain, $path ){
 			$url = 'http://' . $domain . $path;
 		}
 	}
-	return $url;
+	return clean_url($url);
 }
 
 function get_sitestats() {
@@ -125,11 +127,11 @@ function get_blog_details( $id, $getall = true ) {
 		return $details;
 	}
 
-	$wpdb->hide_errors();
+	$wpdb->suppress_errors();
 	$details->blogname   = get_blog_option($id, 'blogname');
 	$details->siteurl    = get_blog_option($id, 'siteurl');
 	$details->post_count = get_blog_option($id, 'post_count');
-	$wpdb->show_errors();
+	$wpdb->suppress_errors( false );
 
 	$details = apply_filters('blog_details', $details);
 
@@ -231,7 +233,7 @@ function update_site_option( $key, $value ) {
 	$safe_key = $wpdb->escape( $key );
 
 	if ( $value == get_site_option( $key ) )
-	 	return;
+	 	return false;
 
 	$exists = $wpdb->get_row("SELECT meta_value FROM $wpdb->sitemeta WHERE meta_key = '$safe_key' AND site_id = '{$wpdb->siteid}'");
 
@@ -243,6 +245,7 @@ function update_site_option( $key, $value ) {
 
 	$wpdb->query( "UPDATE $wpdb->sitemeta SET meta_value = '" . $wpdb->escape( $value ) . "' WHERE site_id='{$wpdb->siteid}' AND meta_key = '$safe_key'" );
 	wp_cache_delete( $wpdb->siteid . $key, 'site-options' );
+	return true;
 }
 
 /*
@@ -309,113 +312,70 @@ function delete_blog_option( $id, $key ) {
 
 function update_blog_option( $id, $key, $value, $refresh = true ) {
 	switch_to_blog($id);
-	$opt = update_option( $key, $value );
+	update_option( $key, $value );
 	restore_current_blog();
-	if( $refresh == true )
+	
+	if( $refresh == true ) {
 		refresh_blog_details( $id );
-	$opt = $id."-".$key."-blog_option";
-	wp_cache_set($opt, $value, 'site-options');
+	}
+	wp_cache_set( $id."-".$key."-blog_option", $value, 'site-options');
 }
 
 function switch_to_blog( $new_blog ) {
-	global $tmpoldblogdetails, $wpdb, $table_prefix, $blog_id, $switched, $switched_stack, $wp_roles, $current_user;
+	global $wpdb, $table_prefix, $blog_id, $switched, $switched_stack, $wp_roles, $current_user, $wp_object_cache;
 
 	if ( empty($new_blog) )
-		$new_blog = $blog_id;
+		return;
+
+	if ( $blog_id == $new_blog )
+		return;
 
 	if ( empty($switched_stack) )
 		$switched_stack = array();
 
 	$switched_stack[] = $blog_id;
 
-	// backup
-	$tmpoldblogdetails['blogid']         = $wpdb->blogid;
-	$tmpoldblogdetails['posts']          = $wpdb->posts;
-	$tmpoldblogdetails['categories']     = $wpdb->categories;
-	$tmpoldblogdetails['post2cat']       = $wpdb->post2cat;
-	$tmpoldblogdetails['comments']       = $wpdb->comments;
-	$tmpoldblogdetails['links']          = $wpdb->links;
-	$tmpoldblogdetails['link2cat']       = $wpdb->link2cat;
-	$tmpoldblogdetails['linkcategories'] = $wpdb->linkcategories;
-	$tmpoldblogdetails['options']        = $wpdb->options;
-	$tmpoldblogdetails['postmeta']       = $wpdb->postmeta;
-	$tmpoldblogdetails['terms']          = $wpdb->terms;
-	$tmpoldblogdetails['term_taxonomy']  = $wpdb->term_taxonomy;
-	$tmpoldblogdetails['term_relationships'] = $wpdb->term_relationships;
-	$tmpoldblogdetails['prefix']         = $wpdb->prefix;
-	$tmpoldblogdetails['table_prefix']   = $table_prefix;
-	$tmpoldblogdetails['blog_id']        = $blog_id;
-
-	// fix the new prefix.
-	$table_prefix = $wpdb->base_prefix . $new_blog . "_";
-	$wpdb->prefix			= $table_prefix;
-	$wpdb->blogid           = $new_blog;
-	$wpdb->posts            = $table_prefix . 'posts';
-	$wpdb->categories       = $table_prefix . 'categories';
-	$wpdb->post2cat         = $table_prefix . 'post2cat';
-	$wpdb->comments         = $table_prefix . 'comments';
-	$wpdb->links            = $table_prefix . 'links';
-	$wpdb->link2cat         = $table_prefix . 'link2cat';
-	$wpdb->linkcategories   = $table_prefix . 'linkcategories';
-	$wpdb->options          = $table_prefix . 'options';
-	$wpdb->postmeta         = $table_prefix . 'postmeta';
-	$wpdb->terms            = $table_prefix . 'terms';
-	$wpdb->term_taxonomy    = $table_prefix . 'term_taxonomy';
-	$wpdb->term_relationships = $table_prefix . 'term_relationships';
+	$wpdb->set_blog_id($new_blog);
+	$table_prefix = $wpdb->prefix;
 	$blog_id = $new_blog;
 
 	if( is_object( $wp_roles ) ) {
-		$wpdb->hide_errors();
+		$wpdb->suppress_errors();
 		$wp_roles->_init();
-		$wpdb->show_errors();
-	}
-	if ( is_object( $current_user ) ) {
-		$current_user->_init_caps();
+		$wpdb->suppress_errors( false );
 	}
 
-	do_action('switch_blog', $blog_id, $tmpoldblogdetails['blog_id']);
+	if ( is_object( $current_user ) )
+		$current_user->_init_caps();
+
+	do_action('switch_blog', $blog_id, array());
 	$switched = true;
 }
 
 function restore_current_blog() {
-	global $table_prefix, $tmpoldblogdetails, $wpdb, $blog_id, $switched, $switched_stack, $wp_roles, $current_user;
+	global $table_prefix, $wpdb, $blog_id, $switched, $switched_stack, $wp_roles, $current_user, $wp_object_cache;
 
 	if ( !$switched )
 		return;
 
 	$blog = array_pop($switched_stack);
-
 	if ( $blog_id == $blog )
 		return;
 
-	// backup
-	$wpdb->blogid = $tmpoldblogdetails['blogid'];
-	$wpdb->posts = $tmpoldblogdetails['posts'];
-	$wpdb->categories = $tmpoldblogdetails['categories'];
-	$wpdb->post2cat = $tmpoldblogdetails['post2cat'];
-	$wpdb->comments = $tmpoldblogdetails['comments'];
-	$wpdb->links = $tmpoldblogdetails['links'];
-	$wpdb->link2cat = $tmpoldblogdetails['link2cat'];
-	$wpdb->linkcategories = $tmpoldblogdetails['linkcategories'];
-	$wpdb->options = $tmpoldblogdetails['options'];
-	$wpdb->postmeta = $tmpoldblogdetails['postmeta'];
-	$wpdb->terms = $tmpoldblogdetails['terms'];
-	$wpdb->term_taxonomy = $tmpoldblogdetails['term_taxonomy'];
-	$wpdb->term_relationships = $tmpoldblogdetails['term_relationships'];
-	$wpdb->prefix = $tmpoldblogdetails['prefix'];
-	$table_prefix = $tmpoldblogdetails['table_prefix'];
+	$wpdb->set_blog_id($blog);
 	$prev_blog_id = $blog_id;
-	$blog_id = $tmpoldblogdetails['blog_id'];
-	unset( $tmpoldblogdetails );
+	$blog_id = $blog;
+	$table_prefix = $wpdb->prefix;
 
 	if( is_object( $wp_roles ) ) {
-		$wpdb->hide_errors();
+		$wpdb->suppress_errors();
 		$wp_roles->_init();
-		$wpdb->show_errors();
+		$wpdb->suppress_errors( false );
 	}
-	if ( is_object( $current_user ) ) {
+
+	if ( is_object( $current_user ) )
 		$current_user->_init_caps();
-	}
+
 	do_action('switch_blog', $blog_id, $prev_blog_id);
 
 	$switched = false;
@@ -428,9 +388,7 @@ function get_blogs_of_user( $id, $all = false ) {
 	if ( !$user )
 		return false;
 
-	$blogs = array();
-
-	$i = 0;
+	$blogs = $match = array();
 	foreach ( (array) $user as $key => $value ) {
 		if ( strstr( $key, '_capabilities') && strstr( $key, 'wp_') ) {
 			preg_match('/' . $wpdb->base_prefix . '(\d+)_capabilities/', $key, $match);
@@ -534,7 +492,6 @@ function get_last_updated( $display = false ) {
 }
 
 function get_most_active_blogs( $num = 10, $display = true ) {
-	global $wpdb;
 	$most_active = get_site_option( "most_active" );
 	$update = false;
 	if( is_array( $most_active ) ) {
@@ -569,7 +526,7 @@ function get_most_active_blogs( $num = 10, $display = true ) {
 		if( is_array( $most_active ) ) {
 			reset( $most_active );
 			foreach ( (array) $most_active as $key => $details ) {
-				$url = "http://" . $details['domain'] . $details['path'];
+				$url = clean_url("http://" . $details['domain'] . $details['path']);
 				echo "<li>" . $details['postcount'] . " <a href='$url'>$url</a></li>";
 			}
 		}
@@ -594,7 +551,7 @@ function get_blog_list( $start = 0, $num = 10, $display = true ) {
 		unset( $blogs );
 		$blogs = $wpdb->get_results( "SELECT blog_id, domain, path FROM $wpdb->blogs WHERE site_id = '$wpdb->siteid' AND public = '1' AND archived = '0' AND mature = '0' AND spam = '0' AND deleted = '0' ORDER BY registered DESC", ARRAY_A );
 
-		foreach ( (array) $blogs as $key => $details ) {
+		foreach ( (array) $blogs as $details ) {
 			$blog_list[ $details['blog_id'] ] = $details;
 			$blog_list[ $details['blog_id'] ]['postcount'] = $wpdb->get_var( "SELECT count(*) FROM " . $wpdb->base_prefix . $details['blog_id'] . "_posts WHERE post_status='publish' AND post_type='post'" );
 		}
@@ -661,15 +618,12 @@ function add_user_to_blog( $blog_id, $user_id, $role ) {
 	do_action('add_user_to_blog', $user_id, $role, $blog_id);
 	wp_cache_delete( $user_id, 'users' );
 	restore_current_blog();
+	return true;
 }
 
 function remove_user_from_blog($user_id, $blog_id = '') {
-	global $wpdb;
-
 	switch_to_blog($blog_id);
-
 	$user_id = (int) $user_id;
-
 	do_action('remove_user_from_blog', $user_id, $blog_id);
 
 	// If being removed from the primary blog, set a new primary if the user is assigned
@@ -703,8 +657,6 @@ function remove_user_from_blog($user_id, $blog_id = '') {
 }
 
 function create_empty_blog( $domain, $path, $weblog_title, $site_id = 1 ) {
-	global $wpdb;
-
 	$domain       = addslashes( $domain );
 	$weblog_title = addslashes( $weblog_title );
 
@@ -726,7 +678,7 @@ function create_empty_blog( $domain, $path, $weblog_title, $site_id = 1 ) {
 	install_blog($blog_id);
 	restore_current_blog();
 
-	return true;
+	return $blog_id;
 }
 
 function get_blog_permalink( $blog_id, $post_id ) {
@@ -842,7 +794,7 @@ function is_email_address_unsafe( $user_email ) {
 }
 
 function wpmu_validate_user_signup($user_name, $user_email) {
-	global $wpdb, $current_site;
+	global $wpdb;
 
 	$errors = new WP_Error();
 
@@ -852,6 +804,7 @@ function wpmu_validate_user_signup($user_name, $user_email) {
 	if ( empty( $user_name ) )
 	   	$errors->add('user_name', __("Please enter a username"));
 
+	$maybe = array();
 	preg_match( "/[a-z0-9]+/", $user_name, $maybe );
 
 	if( $user_name != $maybe[0] ) {
@@ -878,6 +831,7 @@ function wpmu_validate_user_signup($user_name, $user_email) {
 		$errors->add('user_name', __("Sorry, usernames may not contain the character '_'!"));
 
 	// all numeric?
+	$match = array();
 	preg_match( '/[0-9]*/', $user_name, $match );
 	if ( $match[0] == $user_name )
 		$errors->add('user_name', __("Sorry, usernames must have letters too!"));
@@ -955,6 +909,7 @@ function wpmu_validate_blog_signup($blog_id, $blog_title, $user = '') {
 	if ( empty( $blog_id ) )
 	    $errors->add('blog_id', __("Please enter a blog name"));
 
+	$maybe = array();
 	preg_match( "/[a-z0-9]+/", $blog_id, $maybe );
 	if( $blog_id != $maybe[0] ) {
 	    $errors->add('blog_id', __("Only lowercase letters and numbers allowed"));
@@ -970,6 +925,7 @@ function wpmu_validate_blog_signup($blog_id, $blog_title, $user = '') {
 		$errors->add('blog_id', __("Sorry, blog names may not contain the character '_'!"));
 
 	// all numeric?
+	$match = array();
 	preg_match( '/[0-9]*/', $blog_id, $match );
 	if ( $match[0] == $blog_id )
 		$errors->add('blog_id', __("Sorry, blog names must have letters too!"));
@@ -1053,32 +1009,41 @@ function wpmu_signup_user($user, $user_email, $meta = '') {
 // Notify user of signup success.
 function wpmu_signup_blog_notification($domain, $path, $title, $user, $user_email, $key, $meta = '') {
 	global $current_site;
+
+	if( !apply_filters('wpmu_signup_blog_notification', $domain, $path, $title, $user, $user_email, $key, $meta) )
+		return;
+
 	// Send email with activation link.
 	if( constant( "VHOST" ) == 'no' ) {
 		$activate_url = "http://" . $current_site->domain . $current_site->path . "wp-activate.php?key=$key";
 	} else {
 		$activate_url = "http://{$domain}{$path}wp-activate.php?key=$key";
 	}
+	$activate_url = clean_url($activate_url);
 	$admin_email = get_site_option( "admin_email" );
 	if( $admin_email == '' )
 		$admin_email = 'support@' . $_SERVER['SERVER_NAME'];
 	$from_name = get_site_option( "site_name" ) == '' ? 'WordPress' : wp_specialchars( get_site_option( "site_name" ) );
 	$message_headers = "MIME-Version: 1.0\n" . "From: \"{$from_name}\" <{$admin_email}>\n" . "Content-Type: text/plain; charset=\"" . get_option('blog_charset') . "\"\n";
-	$message = sprintf(__("To activate your blog, please click the following link:\n\n%s\n\nAfter you activate, you will receive *another email* with your login.\n\nAfter you activate, you can visit your blog here:\n\n%s"), $activate_url, "http://{$domain}{$path}");
+	$message = sprintf(__("To activate your blog, please click the following link:\n\n%s\n\nAfter you activate, you will receive *another email* with your login.\n\nAfter you activate, you can visit your blog here:\n\n%s"), $activate_url, clean_url("http://{$domain}{$path}"));
 	// TODO: Don't hard code activation link.
-	$subject = '[' . $from_name . '] ' . sprintf(__('Activate %s'), 'http://' . $domain . $path);
+	$subject = '[' . $from_name . '] ' . sprintf(__('Activate %s'), clean_url('http://' . $domain . $path));
 	wp_mail($user_email, $subject, $message, $message_headers);
 }
 
 function wpmu_signup_user_notification($user, $user_email, $key, $meta = '') {
 	global $current_site;
+
+	if( !apply_filters('wpmu_signup_user_notification', $user, $user_email, $key, $meta) )
+		return;
+
 	// Send email with activation link.
 	$admin_email = get_site_option( "admin_email" );
 	if( $admin_email == '' )
 		$admin_email = 'support@' . $_SERVER['SERVER_NAME'];
 	$from_name = get_site_option( "site_name" ) == '' ? 'WordPress' : wp_specialchars( get_site_option( "site_name" ) );
 	$message_headers = "MIME-Version: 1.0\n" . "From: \"{$from_name}\" <{$admin_email}>\n" . "Content-Type: text/plain; charset=\"" . get_option('blog_charset') . "\"\n";
-	$message = sprintf(__("To activate your user, please click the following link:\n\n%s\n\nAfter you activate, you will receive *another email* with your login.\n\n"), "http://{$current_site->domain}{$current_site->path}wp-activate.php?key=$key" );
+	$message = sprintf(__("To activate your user, please click the following link:\n\n%s\n\nAfter you activate, you will receive *another email* with your login.\n\n"), clean_url("http://{$current_site->domain}{$current_site->path}wp-activate.php?key=$key") );
 	// TODO: Don't hard code activation link.
 	$subject = sprintf(__('Activate %s'), $user);
 	wp_mail($user_email, $subject, $message, $message_headers);
@@ -1087,7 +1052,6 @@ function wpmu_signup_user_notification($user, $user_email, $key, $meta = '') {
 function wpmu_activate_signup($key) {
 	global $wpdb;
 
-	$result = array();
 	$signup = $wpdb->get_row("SELECT * FROM $wpdb->signups WHERE activation_key = '$key'");
 
 	if ( empty($signup) )
@@ -1134,7 +1098,6 @@ function wpmu_activate_signup($key) {
 		if ( 'blog_taken' == $blog_id->get_error_code() ) {
 			$blog_id->add_data($signup);
 			$wpdb->query("UPDATE $wpdb->signups SET active = '1', activated = '$now' WHERE activation_key = '$key'");
-			error_log("Blog $blog_id failed to complete activation.", 0);	
 		}
 
 		return $blog_id;
@@ -1207,6 +1170,8 @@ function wpmu_create_blog($domain, $path, $title, $user_id, $meta = '', $site_id
 		update_blog_option( $blog_id, $key, $value );
 	}
 
+	add_blog_option( $blog_id, 'WPLANG', get_site_option( 'WPLANG' ) );
+
 	update_blog_option( $blog_id, 'blog_public', $meta['public'] );
 	delete_blog_option( $blog_id, 'public' );
 
@@ -1223,26 +1188,43 @@ function newblog_notify_siteadmin( $blog_id, $user_id ) {
 	global $current_site;
 	if( get_site_option( 'registrationnotification' ) != 'yes' )
 		return;
+		
 	$email = get_site_option( 'admin_email' );
-	if( is_email( $email ) == false )
+	if( is_email($email) == false )
 		return false;
-	$msg = "New Blog: " . get_blog_option( $blog_id, "blogname" ) . "\nURL: " . get_blog_option( $blog_id, "siteurl" ) . "\nRemote IP: {$_SERVER['REMOTE_ADDR']}\n\nDisable these notifications: http://{$current_site->domain}{$current_site->path}wp-admin/wpmu-options.php";
+	
+	$options_site_url = clean_url("http://{$current_site->domain}{$current_site->path}wp-admin/wpmu-options.php");
+	
+	$msg = sprintf(__("New Blog: %1s
+URL: %2s
+Remote IP: %3s
+
+Disable these notifications: %4s"), get_blog_option( $blog_id, "blogname" ), get_blog_option( $blog_id, "siteurl" ), $_SERVER['REMOTE_ADDR'], $options_site_url);
 	$msg = apply_filters( 'newblog_notify_siteadmin', $msg );
-	wp_mail( $email, "New Blog Registration: " . get_blog_option( $blog_id, "siteurl" ), $msg );
+	
+	wp_mail( $email, sprintf(__("New Blog Registration: %s"), get_blog_option( $blog_id, "siteurl" )), $msg );
 }
 add_action( "wpmu_new_blog", "newblog_notify_siteadmin", 10, 2 );
 
 function newuser_notify_siteadmin( $user_id ) {
 	global $current_site;
 	if( get_site_option( 'registrationnotification' ) != 'yes' )
-		return;
+		return false;
+		
 	$email = get_site_option( 'admin_email' );
-	if( is_email( $email ) == false )
+	if( is_email($email) == false )
 		return false;
 	$user = new WP_User($user_id);
-	$msg = "New User: " . $user->user_login . "\nRemote IP: {$_SERVER['REMOTE_ADDR']}\n\nDisable these notifications: http://{$current_site->domain}{$current_site->path}wp-admin/wpmu-options.php";
+
+	$options_site_url = clean_url("http://{$current_site->domain}{$current_site->path}wp-admin/wpmu-options.php");
+	$msg = sprintf(__("New User: %1s
+Remote IP: %2s
+
+Disable these notifications: %3s"), $user->user_login, $_SERVER['REMOTE_ADDR'], $options_site_url);
+	
 	$msg = apply_filters( 'newuser_notify_siteadmin', $msg );
-	wp_mail( $email, "New User Registration: " . $user->user_login, $msg );
+	wp_mail( $email, sprintf(__("New User Registration: %s"), $user->user_login), $msg );
+	return true;
 }
 add_action( "wpmu_new_user", "newuser_notify_siteadmin" );
 
@@ -1253,28 +1235,28 @@ function domain_exists($domain, $path, $site_id = 1) {
 
 function insert_blog($domain, $path, $site_id) {
 	global $wpdb;
-	$path = trailingslashit( $path );
-	$query = "INSERT INTO $wpdb->blogs ( blog_id, site_id, domain, path, registered ) VALUES ( NULL, '$site_id', '$domain', '$path', NOW( ))";
-	$result = $wpdb->query( $query );
-	if ( ! $result )
+	$path = trailingslashit($path);
+	$site_id = (int) $site_id;
+	
+	$result = $wpdb->query( "INSERT INTO $wpdb->blogs ( blog_id, site_id, domain, path, registered ) VALUES ( NULL, '$site_id', '$domain', '$path', NOW( ))" );
+	if ( !$result )
 		return false;
 
-	$id = $wpdb->insert_id;
-	refresh_blog_details($id);
-	return $id;
+	refresh_blog_details($wpdb->insert_id);
+	return $wpdb->insert_id;
 }
 
 // Install an empty blog.  wpdb should already be switched.
 function install_blog($blog_id, $blog_title = '') {
 	global $wpdb, $table_prefix, $wp_roles;
-	$wpdb->hide_errors();
 
 	require_once( ABSPATH . 'wp-admin/includes/upgrade.php');
+	$wpdb->suppress_errors();
 	$installed = $wpdb->get_results("SELECT * FROM $wpdb->posts");
+	$wpdb->suppress_errors( false);
 	if ($installed) die(__('<h1>Already Installed</h1><p>You appear to have already installed WordPress. To reinstall please clear your old database tables first.</p>') . '</body></html>');
 
 	$url = get_blogaddress_by_id($blog_id);
-	error_log("install_blog - ID: $blog_id  URL: $url Title: $blog_title ", 0);
 
 	// Set everything up
 	make_db_current_silent();
@@ -1316,13 +1298,13 @@ function install_blog($blog_id, $blog_title = '') {
 	$wpdb->query( "DELETE FROM ".$wpdb->usermeta." WHERE meta_key = '".$table_prefix."user_level'" );
 	$wpdb->query( "DELETE FROM ".$wpdb->usermeta." WHERE meta_key = '".$table_prefix."capabilities'" );
 
-	$wpdb->show_errors();
+	$wpdb->suppress_errors( false );
 }
 
 function install_blog_defaults($blog_id, $user_id) {
 	global $wpdb, $wp_rewrite, $current_site, $table_prefix;
 
-	$wpdb->hide_errors();
+	$wpdb->suppress_errors();
 
 	// Default links
 	$wpdb->query("INSERT INTO $wpdb->links (link_url, link_name, link_category, link_owner, link_rss) VALUES ('http://wordpress.com/', 'WordPress.com', 1356, '$user_id', 'http://wordpress.com/feed/');");
@@ -1337,7 +1319,7 @@ function install_blog_defaults($blog_id, $user_id) {
 	if( $first_post == false )
 		$first_post = stripslashes( __( 'Welcome to <a href="SITE_URL">SITE_NAME</a>. This is your first post. Edit or delete it, then start blogging!' ) );
 
-	$first_post = str_replace( "SITE_URL", "http://" . $current_site->domain . $current_site->path, $first_post );
+	$first_post = str_replace( "SITE_URL", clean_url("http://" . $current_site->domain . $current_site->path), $first_post );
 	$first_post = str_replace( "SITE_NAME", $current_site->site_name, $first_post );
 	$first_post = stripslashes( $first_post );
 
@@ -1361,15 +1343,18 @@ function install_blog_defaults($blog_id, $user_id) {
 	$wpdb->query( "DELETE FROM ".$wpdb->usermeta." WHERE  user_id != '".$user_id."' AND meta_key = '".$table_prefix."user_level'" );
 	$wpdb->query( "DELETE FROM ".$wpdb->usermeta." WHERE  user_id != '".$user_id."' AND meta_key = '".$table_prefix."capabilities'" );
 	// Delete any caps that snuck into the previously active blog. (Hardcoded to blog 1 for now.) TODO: Get previous_blog_id.
-	if ( $user_id != 1 )
+	if ( !is_site_admin( $user->user_login ) && $user_id != 1 )
 		$wpdb->query( "DELETE FROM ".$wpdb->usermeta." WHERE  user_id = '".$user_id."' AND meta_key = '" . $wpdb->base_prefix . "1_capabilities'" );
 
-	$wpdb->show_errors();
+	$wpdb->suppress_errors( false );
 }
 
 function wpmu_welcome_notification($blog_id, $user_id, $password, $title, $meta = '') {
 	global $current_site;
 
+	if( !apply_filters('wpmu_welcome_notification', $blog_id, $user_id, $password, $title, $meta) )
+		return;
+
 	$welcome_email = stripslashes( get_site_option( 'welcome_email' ) );
 	if( $welcome_email == false )
 		$welcome_email = stripslashes( __( "Dear User,
@@ -1412,6 +1397,9 @@ SITE_NAME" ) );
 function wpmu_welcome_user_notification($user_id, $password, $meta = '') {
 	global $current_site;
 
+	if( !apply_filters('wpmu_welcome_user_notification', $user_id, $password, $meta) )
+		return;
+
 	$welcome_email = __( "Dear User,
 
 Your new account is setup.
@@ -1534,8 +1522,6 @@ function get_dirsize($directory) {
 }
 
 function upload_is_user_over_quota( $echo = true ) {
-	global $wpdb;
-	
 	// Default space allowed is 10 MB 
 	$spaceAllowed = get_space_allowed();
 	if(empty($spaceAllowed) || !is_numeric($spaceAllowed)) $spaceAllowed = 10;
@@ -1559,7 +1545,7 @@ function check_upload_mimes($mimes) {
 	$site_exts = explode( " ", get_site_option( "upload_filetypes" ) );
 	foreach ( $site_exts as $ext )
 		foreach ( $mimes as $ext_pattern => $mime )
-			if ( preg_match("/$ext_pattern/", $ext) )
+			if( strpos( $ext_pattern, $ext ) !== false )
 				$site_mimes[$ext_pattern] = $mime;
 	return $site_mimes;
 }
@@ -1583,20 +1569,16 @@ function wpmu_log_new_registrations( $blog_id, $user_id ) {
 
 add_action( "wpmu_new_blog" ,"wpmu_log_new_registrations", 10, 2 );
 
-function scriptaculous_admin_loader() {
-	        wp_enqueue_script('scriptaculous');
-}
-add_action( 'admin_print_scripts', 'scriptaculous_admin_loader' );
-
 function fix_import_form_size( $size ) {
-	if( upload_is_user_over_quota( false ) == false )
+	if( upload_is_user_over_quota( false ) == true )
 		return 0;
+	$spaceAllowed = 1024 * 1024 * get_space_allowed();
 	$dirName = constant( "ABSPATH" ) . constant( "UPLOADS" );
-	$dirsize = get_dirsize($dirName) / 1024;
-	if( $size > $dirsize ) {
-		return $dirsize;
+	$dirsize = get_dirsize($dirName) ;
+	if( $size > $spaceAllowed - $dirsize ) {
+		return $spaceAllowed - $dirsize; // remaining space
 	} else {
-		return $size;
+		return $size; // default
 	}
 }
 add_filter( 'import_upload_size_limit', 'fix_import_form_size' );
@@ -1634,7 +1616,6 @@ endif;
 /* Delete blog */
 
 class delete_blog {
-
 	function delete_blog() {
 		$this->reallydeleteblog = false;
 		add_action('admin_menu', array(&$this, 'admin_menu'));
@@ -1654,7 +1635,7 @@ class delete_blog {
 	}
 
 	function plugin_content() {
-		global $wpdb, $current_blog, $current_site;
+		global $current_blog, $current_site;
 		$this->delete_blog_hash = get_settings('delete_blog_hash');
 		echo '<div class="wrap"><h2>' . __('Delete Blog') . '</h2>';
 		if( $_POST['action'] == "deleteblog" && $_POST['confirmdelete'] == '1' ) {
@@ -1708,99 +1689,6 @@ SITE_NAME
 
 $delete_blog_obj = new delete_blog();
 
-/* Dashboard Switcher */
-
-add_action( 'admin_print_scripts', 'switcher_scripts' );
-
-function switcher_scripts() {
-	wp_enqueue_script('jquery');
-}
-
-
-function switcher_css() {
-?>
-<style type="text/css">
-#switchermenu a {
-	font-size: 20px;
-	padding: 0 1.5em 0 10px;
-	display: block;
-	color: #c3def1;
-}
-
-#switchermenu a:hover {
-	background: #1a70b4;
-	color: #fff;
-}
-
-#switchermenu li {
-	margin: 0;
-	padding: 2px;
-}
-
-#switchermenu {
-	display: none;
-	list-style: none;
-	margin: 0;
-	padding: 0;
-	overflow: hidden;
-	border-top: 1px solid #1a70b4;
-	border-left: 1px solid #1a70b4;
-	position: absolute;
-	left: 0;
-	top: 1em;
-	background: #14568a;
-	z-index: 1;
-}
-</style>
-<script type="text/javascript">
-jQuery( function($) {
-var switchTime;
-var w = false;
-var h = $( '#blog-title' )
-	.css({
-		background: 'transparent url( ../wp-includes/images/bullet_arrow_down.gif ) no-repeat scroll 100% .2em',
-		padding: '0 25px 2px 5px',
-		cursor: 'pointer',
-		border: '1px solid #14568a'
-	})
-	.parent().css( { position: 'relative' }).end()
-	.append( $('#switchermenu') )
-	.hover( function() {
-		$(this).css({ border: '1px solid #1a70b4'});
-		switchTime = window.setTimeout( function() {
-			$('#switchermenu').fadeIn('fast').css( 'top', h ).find('a').width( w = w ? w : $('#switchermenu').width() );
-		}, 300 );
-	}, function() {
-		window.clearTimeout( switchTime );
-		$(this).css({ border: '1px solid #14568a' }) ;
-		$('#switchermenu').hide();
-	})
-	.height() - 3;
-});
-</script>
-<?php
-}
-add_action( "admin_head", "switcher_css" );
-
-function add_switcher() {
-	global $current_user;
-	$out = '<h1><span id="blog-title">' . wptexturize(get_bloginfo(("name"))) . '</span><span id="viewsite">(<a href="' . get_option("home") . "/" . '">' . __("View site &raquo;") . '</a>)</span></h1>';
-	$out .= '<ul id="switchermenu">';
-	$blogs = get_blogs_of_user($current_user->ID);
-	if ( ! empty($blogs) ) foreach ( $blogs as $blog ) {
-		$out .= '<li><a href="http://' . $blog->domain . $blog->path . 'wp-admin/">' . addslashes( $blog->blogname ) . '</a></li>';
-	}
-	$out .= "</ul>";
-	?>
-	<script type="text/javascript">
-	<!--
-	document.getElementById('wphead').innerHTML = '<?php echo $out ?>'
-	-->
-	</script>
-	<?php
-}
-add_action( 'admin_footer', 'add_switcher' );
-
 /* Global Categories */
 
 function global_terms( $term_id, $tt_id ) {
@@ -1819,38 +1707,44 @@ function global_terms( $term_id, $tt_id ) {
 	if ( $global_id == $term_id )
 		return $global_id;
 
+	if( get_option( 'default_category' ) == $term_id )
+		update_option( 'default_category', $global_id );
 	$wpdb->query( "UPDATE $wpdb->terms SET term_id = '$global_id' WHERE term_id = '$term_id'" ); 
 	$wpdb->query( "UPDATE $wpdb->term_taxonomy SET term_id = '$global_id' WHERE term_id = '$term_id'" );
 	$wpdb->query( "UPDATE $wpdb->term_taxonomy SET parent = '$global_id' WHERE parent = '$term_id'" );
 
-	$wpdb->query( "UPDATE $wpdb->categories SET cat_ID = '$global_id' WHERE cat_ID = '$term_id'" );
-	$wpdb->query( "UPDATE $wpdb->categories SET category_parent = '$global_id' WHERE category_parent = '$term_id'" );
-
-	clean_term_cache($global_id, 'category');
-	clean_term_cache($global_id, 'post_tag');
+	clean_term_cache($term_id);
 
 	return $global_id; 
 }   
 add_filter( 'term_id_filter', 'global_terms', 10, 2 ); // taxonomy specific filter
 
-/* WordPress MU Default Filters */
-add_filter('the_title', 'wp_filter_kses');
-
 function choose_primary_blog() {
 	global $current_user;
-	echo __('Primary Blog:') . ' ';
-	$all_blogs = get_blogs_of_user( $current_user->ID );
-	if( count( $all_blogs ) > 1 ) {
-		$primary_blog = get_usermeta($current_user->ID, 'primary_blog');
+	?>
+	<table class="form-table">
+	<tr>
+		<th scope="row"><?php _e('Primary Blog:'); ?></th>
+		<td>
+		<?php
+		$all_blogs = get_blogs_of_user( $current_user->ID );
+		if( count( $all_blogs ) > 1 ) {
+			$primary_blog = get_usermeta($current_user->ID, 'primary_blog');
+			?>
+			<select name="primary_blog">
+				<?php foreach( (array) $all_blogs as $blog ) { ?>
+					<option value='<?php echo $blog->userblog_id ?>'<?php if( $primary_blog == $blog->userblog_id ) echo ' selected="selected"' ?>>http://<?php echo $blog->domain.$blog->path ?></option>
+				<?php } ?>
+			</select>
+			<?php
+		} else {
+			echo $_SERVER['HTTP_HOST'];
+		}
 		?>
-		<p><select name="primary_blog">
-			<?php foreach( (array) $all_blogs as $blog ) { ?>
-				<option value='<?php echo $blog->userblog_id ?>'<?php if( $primary_blog == $blog->userblog_id ) echo ' selected="selected"' ?>>http://<?php echo $blog->domain.$blog->path ?></option>
-			<?php } ?>
-		</select></p><?php
-	} else {
-		echo $_SERVER['HTTP_HOST'];
-	}       
+		</td>
+	</tr>
+	</table>
+	<?php	
 }
 add_action( 'profile_personal_options', 'choose_primary_blog' );
 
@@ -1859,4 +1753,158 @@ function redirect_this_site( $hosts ) {
 	return array( $current_site->domain );
 }
 add_filter( 'allowed_redirect_hosts', 'redirect_this_site' );
+
+function upload_is_file_too_big( $upload ) {
+	if( is_array( $upload ) == false || defined( 'WP_IMPORTING' ) )
+		return $upload;
+	if( strlen( $upload[ 'bits' ] )  > ( 1024 * get_site_option( 'fileupload_maxk', 1500 ) ) ) {
+		return sprintf(__( "This file is too big. Files must be less than %dKb in size.<br />" ), get_site_option( 'fileupload_maxk', 1500 )); 
+	}
+
+	return $upload;
+}
+add_filter( "wp_upload_bits", "upload_is_file_too_big" );
+
+function safecss_filter_attr( $css, $element ) {
+	$css = wp_kses_no_null($css);
+	$css = str_replace(array("\n","\r","\t"), '', $css);
+	$css_array = split( ';', trim( $css ) );
+	$allowed_attr = apply_filters( 'safe_style_css', array( 'text-align', 'margin', 'color', 'float', 
+	'text-direction', 'font', 'font-family', 'font-size', 'font-style', 'font-variant', 'font-weight', 'height',
+	'margin-bottom', 'margin-left', 'margin-right', 'margin-top', 'padding', 'padding-bottom',
+	'padding-left', 'padding-right', 'padding-top', 'width', 'border', 'vertical-align', 'text-decoration' ) );
+	$css = '';
+	foreach( $css_array as $css_item ) {
+		if( $css_item == '' )
+			continue;
+		$css_item = trim( $css_item );
+		$found = false;
+		if( strpos( $css_item, ':' ) === false ) {
+			$found = true;
+		} elseif( in_array( substr( $css_item, 0, strpos( $css_item, ':' ) ), $allowed_attr ) ) {
+			$found = true;
+		}
+		if( $found ) {
+			if( $css != '' )
+				$css .= ';';
+			$css .= $css_item;
+		}
+	}
+
+	return $css;
+}
+
+function wordpressmu_authenticate_siteadmin( $user, $password ) {
+	if( is_site_admin( $user->user_login ) == false && ( $primary_blog = get_usermeta( $user->user_id, "primary_blog" ) ) ) {
+		$details = get_blog_details( $primary_blog );
+		if( is_object( $details ) && $details->spam == 1 ) {
+			return new WP_Error('blog_suspended', __('Blog Suspended.'));
+		}
+	}
+	return $user;
+}
+add_filter( 'wp_authenticate_user', 'wordpressmu_authenticate_siteadmin', 10, 2 );
+
+function wordpressmu_wp_mail_from( $email ) {
+	if( strpos( $email, 'wordpress@' ) !== false )
+		$email = get_option( 'admin_email' );
+	return $email;
+}
+add_filter( 'wp_mail_from', 'wordpressmu_wp_mail_from' );
+
+/*
+XMLRPC getUsersBlogs() for a multiblog environment
+http://trac.mu.wordpress.org/attachment/ticket/551/xmlrpc-mu.php
+*/
+function wpmu_blogger_getUsersBlogs($args) {
+	$site_details = get_blog_details( 1, true );
+	$domain = $site_details->domain;
+	$path = $site_details->path . 'xmlrpc.php';
+
+	$rpc = new IXR_Client("http://{$domain}{$path}");
+	$rpc->query('wp.getUsersBlogs', $args[1], $args[2]);
+	$blogs = $rpc->getResponse();
+
+	if ( isset($blogs['faultCode']) ) {
+		return new IXR_Error($blogs['faultCode'], $blogs['faultString']);
+	}
+
+	if ( $_SERVER['HTTP_HOST'] == $domain && $_SERVER['REQUEST_URI'] == $path ) {
+		return $blogs;
+	} else {
+		foreach ( (array) $blogs as $blog ) {
+			if ( strpos($blog['url'], $_SERVER['HTTP_HOST']) )
+				return array($blog);
+		}
+		return array();
+	}
+}
+
+function attach_wpmu_xmlrpc($methods) {
+	$methods['blogger.getUsersBlogs'] = 'wpmu_blogger_getUsersBlogs';
+	return $methods;
+}
+add_filter('xmlrpc_methods', 'attach_wpmu_xmlrpc');
+
+/*
+Users
+*/
+function promote_if_site_admin(&$user) {
+    if ( !is_site_admin( $user->user_login ) )
+        return;
+
+    global $wpdb;
+    $level = $wpdb->prefix . 'user_level';
+    $user->{$level} = 10;
+    $user->user_level = 10;
+    $cap_key = $wpdb->prefix . 'capabilities';
+    $user->{$cap_key} = array( 'administrator' => '1' );
+}
+
+if( is_object( $wp_object_cache ) ) {
+	$wp_object_cache->global_groups = array ('users', 'userlogins', 'usermeta', 'site-options', 'site-lookup', 'blog-lookup', 'blog-details', 'rss');
+	$wp_object_cache->non_persistent_groups = array('comment', 'counts');
+}
+
+// support a GET parameter for disabling the flash uploader
+function wpmu_upload_flash($flash) {
+	if ( array_key_exists('flash', $_REQUEST) )
+		$flash = !empty($_REQUEST['flash']);
+	return $flash;
+}   
+
+add_filter('flash_uploader', 'wpmu_upload_flash');
+
+function wpmu_upload_flash_bypass() {
+	echo '<p class="upload-flash-bypass">';
+	printf( __('You are using the Flash uploader.  Problems?  Try the <a href="%s">Browser uploader</a> instead.'), add_query_arg('flash', 0) );
+	echo '</p>';
+}
+
+add_action('post-flash-upload-ui', 'wpmu_upload_flash_bypass');
+
+function wpmu_upload_html_bypass() {
+	echo '<p class="upload-html-bypass">';
+	if ( array_key_exists('flash', $_REQUEST) )
+		// the user manually selected the browser uploader, so let them switch back to Flash
+		printf( __('You are using the Browser uploader.  Try the <a href="%s">Flash uploader</a> instead.'), add_query_arg('flash', 1) );
+	else
+		// the user probably doesn't have Flash
+		printf( __('You are using the Browser uploader.') );
+
+	echo '</p>';
+}
+
+add_action('post-flash-upload-ui', 'wpmu_upload_flash_bypass');
+add_action('post-html-upload-ui', 'wpmu_upload_html_bypass');
+
+// make sure the GET parameter sticks when we submit a form
+function wpmu_upload_bypass_url($url) {
+	if ( array_key_exists('flash', $_REQUEST) )
+		$url = add_query_arg('flash', intval($_REQUEST['flash']));
+	return $url;
+}
+
+add_filter('media_upload_form_url', 'wpmu_upload_bypass_url');
+
 ?>
