@@ -1,8 +1,28 @@
 <?php
-if( defined( 'ABSPATH' ) == false )
-	die();
+/**
+ * Used to setup and fix common variables and include
+ * the WordPress procedural and class library.
+ *
+ * You should not have to change this file and allows
+ * for some configuration in wp-config.php.
+ *
+ * @package WordPress
+ */
 
-// Turn register globals off
+if ( !defined('WP_MEMORY_LIMIT') )
+	define('WP_MEMORY_LIMIT', '32M');
+
+if ( function_exists('memory_get_usage') && ( (int) @ini_get('memory_limit') < abs(intval(WP_MEMORY_LIMIT)) ) )
+	@ini_set('memory_limit', WP_MEMORY_LIMIT);
+
+
+/**
+ * wp_unregister_GLOBALS() - Turn register globals off
+ *
+ * @access private
+ * @since 2.1.0
+ * @return null Will return null if register_globals PHP directive was disabled
+ */
 function wp_unregister_GLOBALS() {
 	if ( !ini_get('register_globals') )
 		return;
@@ -23,13 +43,15 @@ function wp_unregister_GLOBALS() {
 
 wp_unregister_GLOBALS();
 
-if( isset( $_SERVER[ 'HTTP_USER_AGENT' ] ) ) {
-	$HTTP_USER_AGENT = $_SERVER[ 'HTTP_USER_AGENT' ];
-} else {
-	$HTTP_USER_AGENT = '';
-}
-unset( $wp_filter, $cache_userdata, $cache_lastcommentmodified, $cache_lastpostdate, $cache_settings, $category_cache, $cache_categories );
+unset( $wp_filter, $cache_lastcommentmodified, $cache_lastpostdate );
 
+/**
+ * The $blog_id global, which you can change in the config allows you to create a simple
+ * multiple blog installation using just one WordPress and changing $blog_id around.
+ *
+ * @global int $blog_id
+ * @since 2.0.0
+ */
 if ( ! isset($blog_id) )
 	$blog_id = 0;
 
@@ -44,15 +66,15 @@ if ( empty( $_SERVER['REQUEST_URI'] ) ) {
 	else if (isset($_SERVER['HTTP_X_REWRITE_URL'])) {
 		$_SERVER['REQUEST_URI'] = $_SERVER['HTTP_X_REWRITE_URL'];
 	}
-	else {
-		// If root then simulate that no script-name was specified
-		if (empty($_SERVER['PATH_INFO']))
-			$_SERVER['REQUEST_URI'] = substr($_SERVER['SCRIPT_NAME'], 0, strrpos($_SERVER['SCRIPT_NAME'], '/')) . '/';
-		elseif ( $_SERVER['PATH_INFO'] == $_SERVER['SCRIPT_NAME'] )
-			// Some IIS + PHP configurations puts the script-name in the path-info (No need to append it twice)
-			$_SERVER['REQUEST_URI'] = $_SERVER['PATH_INFO'];
-		else
-			$_SERVER['REQUEST_URI'] = $_SERVER['SCRIPT_NAME'] . $_SERVER['PATH_INFO'];
+	else
+	{
+		// Some IIS + PHP configurations puts the script-name in the path-info (No need to append it twice)
+		if ( isset($_SERVER['PATH_INFO']) ) {
+			if ( $_SERVER['PATH_INFO'] == $_SERVER['SCRIPT_NAME'] )
+				$_SERVER['REQUEST_URI'] = $_SERVER['PATH_INFO'];
+			else
+				$_SERVER['REQUEST_URI'] = $_SERVER['SCRIPT_NAME'] . $_SERVER['PATH_INFO'];
+		}
 
 		// Append the query string if it exists and isn't null
 		if (isset($_SERVER['QUERY_STRING']) && !empty($_SERVER['QUERY_STRING'])) {
@@ -74,13 +96,21 @@ $PHP_SELF = $_SERVER['PHP_SELF'];
 if ( empty($PHP_SELF) )
 	$_SERVER['PHP_SELF'] = $PHP_SELF = preg_replace("/(\?.*)?$/",'',$_SERVER["REQUEST_URI"]);
 
-if ( version_compare( '4.2', phpversion(), '>' ) ) {
-	die( 'Your server is running PHP version ' . phpversion() . ' but WordPress requires at least 4.2.' );
+if ( version_compare( '4.3', phpversion(), '>' ) ) {
+	die( 'Your server is running PHP version ' . phpversion() . ' but WordPress requires at least 4.3.' );
 }
 
 if ( !extension_loaded('mysql') && !file_exists(ABSPATH . 'wp-content/db.php') )
-	die( 'Your PHP installation appears to be missing the MySQL which is required for WordPress.' );
+	die( 'Your PHP installation appears to be missing the MySQL extension which is required by WordPress.' );
 
+/**
+ * timer_start() - PHP 4 standard microtime start capture
+ *
+ * @access private
+ * @since 0.71
+ * @global int $timestart Seconds and Microseconds added together from when function is called
+ * @return bool Always returns true
+ */
 function timer_start() {
 	global $timestart;
 	$mtime = explode(' ', microtime() );
@@ -89,6 +119,30 @@ function timer_start() {
 	return true;
 }
 
+/**
+ * timer_stop() - Return and/or display the time from the page start to when function is called.
+ *
+ * You can get the results and print them by doing:
+ * <code>
+ * $nTimePageTookToExecute = timer_stop();
+ * echo $nTimePageTookToExecute;
+ * </code>
+ *
+ * Or instead, you can do:
+ * <code>
+ * timer_stop(1);
+ * </code>
+ * which will do what the above does. If you need the result, you can assign it to a variable, but
+ * most cases, you only need to echo it.
+ *
+ * @since 0.71
+ * @global int $timestart Seconds and Microseconds added together from when timer_start() is called
+ * @global int $timeend  Seconds and Microseconds added together from when function is called
+ *
+ * @param int $display Use '0' or null to not echo anything and 1 to echo the total time
+ * @param int $precision The amount of digits from the right of the decimal to display. Default is 3.
+ * @return float The "second.microsecond" finished time calculation
+ */
 function timer_stop($display = 0, $precision = 3) { //if called like timer_stop(1), will echo $timetotal
 	global $timestart, $timeend;
 	$mtime = microtime();
@@ -103,40 +157,62 @@ function timer_stop($display = 0, $precision = 3) { //if called like timer_stop(
 }
 timer_start();
 
-// Change to E_ALL for development/debugging
-error_reporting(E_ALL ^ E_NOTICE);
+// Add define('WP_DEBUG',true); to wp-config.php to enable display of notices during development.
+if (defined('WP_DEBUG') and WP_DEBUG == true) {
+	error_reporting(E_ALL);
+} else {
+	error_reporting(E_ALL ^ E_NOTICE ^ E_USER_NOTICE);
+}
 
 // For an advanced caching plugin to use, static because you would only want one
 if ( defined('WP_CACHE') )
 	@include ABSPATH . 'wp-content/advanced-cache.php';
 
+/**
+ * Stores the location of the WordPress directory of functions, classes, and core content.
+ *
+ * @since 1.0.0
+ */
 define('WPINC', 'wp-includes');
 
 if ( !defined('LANGDIR') ) {
+	/**
+	 * Stores the location of the language directory. First looks for language folder in wp-content
+	 * and uses that folder if it exists. Or it uses the "languages" folder in WPINC.
+	 *
+	 * @since 2.1.0
+	 */
 	if ( file_exists(ABSPATH . 'wp-content/languages') && @is_dir(ABSPATH . 'wp-content/languages') )
 		define('LANGDIR', 'wp-content/languages'); // no leading slash, no trailing slash
 	else
 		define('LANGDIR', WPINC . '/languages'); // no leading slash, no trailing slash
 }
 
+/**
+ * Allows for the plugins directory to be moved from the default location.
+ *
+ * This isn't used everywhere. Constant is not used in plugin_basename()
+ * which might cause conflicts with changing this.
+ *
+ * @since 2.1
+ */
 if ( !defined('PLUGINDIR') )
 	define('PLUGINDIR', 'wp-content/plugins'); // no leading slash, no trailing slash
 
 require (ABSPATH . WPINC . '/compat.php');
 require (ABSPATH . WPINC . '/functions.php');
+require (ABSPATH . WPINC . '/classes.php');
 
-if ( file_exists(ABSPATH . 'wp-content/db.php') )
-	require_once (ABSPATH . 'wp-content/db.php');
-else
-	require_once (ABSPATH . WPINC . '/wp-db.php');
+require_wp_db();
 
-// $table_prefix is deprecated as of 2.1
-$wpdb->prefix = $wpdb->base_prefix = $table_prefix;
+if ( !empty($wpdb->error) )
+	dead_db();
 
-if ( preg_match('|[^a-z0-9_]|i', $wpdb->prefix) && !file_exists(ABSPATH . 'wp-content/db.php') )
-	wp_die("<strong>ERROR</strong>: <code>$table_prefix</code> in <code>wp-config.php</code> can only contain numbers, letters, and underscores.");
+$prefix = $wpdb->set_prefix($table_prefix);
 
-// Table names
+if ( is_wp_error($prefix) )
+	wp_die('<strong>ERROR</strong>: <code>$table_prefix</code> in <code>wp-config.php</code> can only contain numbers, letters, and underscores.');
+// Table names. prefix is bare "wp_"
 $wpdb->blogs		= $wpdb->prefix . 'blogs';
 $wpdb->site		= $wpdb->prefix . 'site';
 $wpdb->sitemeta		= $wpdb->prefix . 'sitemeta';
@@ -144,14 +220,13 @@ $wpdb->sitecategories	= $wpdb->prefix . 'sitecategories';
 $wpdb->signups		= $wpdb->prefix . 'signups';
 $wpdb->registration_log	= $wpdb->prefix . 'registration_log';
 $wpdb->blog_versions	= $wpdb->prefix . 'blog_versions';
-$wpdb->users		= $wpdb->prefix . 'users';
-$wpdb->usermeta		= $wpdb->prefix . 'usermeta';
 
 if( defined( 'SUNRISE' ) )
 	include_once( ABSPATH . 'wp-content/sunrise.php' );
 
 require_once ( ABSPATH . 'wpmu-settings.php' );
-$wpdb->prefix           = $table_prefix;
+$prefix = $table_prefix;
+$wpdb->prefix           = $table_prefix; // prefix now includes a blog_id
 $wpdb->posts            = $wpdb->prefix . 'posts';
 $wpdb->categories       = $wpdb->prefix . 'categories';
 $wpdb->post2cat         = $wpdb->prefix . 'post2cat';
@@ -161,8 +236,8 @@ $wpdb->links            = $wpdb->prefix . 'links';
 $wpdb->linkcategories   = $wpdb->prefix . 'linkcategories';
 $wpdb->options          = $wpdb->prefix . 'options';
 $wpdb->postmeta         = $wpdb->prefix . 'postmeta';
-$wpdb->terms          = $wpdb->prefix . 'terms';
-$wpdb->term_taxonomy  = $wpdb->prefix . 'term_taxonomy';
+$wpdb->terms            = $wpdb->prefix . 'terms';
+$wpdb->term_taxonomy    = $wpdb->prefix . 'term_taxonomy';
 $wpdb->term_relationships = $wpdb->prefix . 'term_relationships';
 $wpdb->siteid           = $current_blog->site_id;
 $wpdb->blogid           = $current_blog->blog_id;
@@ -172,9 +247,6 @@ if ( defined('CUSTOM_USER_TABLE') )
 if ( defined('CUSTOM_USER_META_TABLE') )
 	$wpdb->usermeta = CUSTOM_USER_META_TABLE;
 
-// To be removed in 2.2
-$tableposts = $tableusers = $tablecategories = $tablepost2cat = $tablecomments = $tablelink2cat = $tablelinks = $tablelinkcategories = $tableoptions = $tablepostmeta = '';
-
 if ( file_exists(ABSPATH . 'wp-content/object-cache.php') )
 	require_once (ABSPATH . 'wp-content/object-cache.php');
 else
@@ -185,7 +257,6 @@ wp_cache_init();
 if( !defined( "UPLOADS" ) )
 	define( "UPLOADS", "wp-content/blogs.dir/{$wpdb->blogid}/files/" );
 
-require (ABSPATH . WPINC . '/classes.php');
 require (ABSPATH . WPINC . '/plugin.php');
 require (ABSPATH . WPINC . '/default-filters.php');
 
@@ -235,12 +306,13 @@ require (ABSPATH . WPINC . '/script-loader.php');
 require (ABSPATH . WPINC . '/taxonomy.php');
 require (ABSPATH . WPINC . '/update.php');
 require (ABSPATH . WPINC . '/canonical.php');
+require (ABSPATH . WPINC . '/shortcodes.php');
+require (ABSPATH . WPINC . '/media.php');
 
 require_once( ABSPATH . WPINC . '/wpmu-functions.php' );
 
-if( defined( "WP_INSTALLING" ) == false ) {
+if( defined( "WP_INSTALLING" ) == false )
 	$current_site->site_name = get_site_option('site_name');
-}
 
 if( $current_site->site_name == false ) {
 	$current_site->site_name = ucfirst( $current_site->domain );
@@ -256,11 +328,13 @@ $wpdb->hide_errors();
 if( defined( 'MUPLUGINDIR' ) == false ) 
 	define( 'MUPLUGINDIR', 'wp-content/mu-plugins' );
 
-$plugins = glob( ABSPATH . MUPLUGINDIR . '/*.php' );
-if( is_array( $plugins ) ) {
-	foreach ( $plugins as $plugin ) {
-		if( is_file( $plugin ) )
-			include_once( $plugin );
+if( is_dir( ABSPATH . MUPLUGINDIR ) ) {
+	if( $dh = opendir( ABSPATH . MUPLUGINDIR ) ) {
+		while( ( $plugin = readdir( $dh ) ) !== false ) {
+			if( substr( $plugin, -4 ) == '.php' ) {
+				include_once( ABSPATH . MUPLUGINDIR . '/' . $plugin );
+			}
+		}
 	}
 }
 $wpdb->show_errors();
@@ -269,7 +343,7 @@ if ( '1' == $current_blog->deleted )
 	graceful_fail(__('This user has elected to delete their account and the content is no longer available.'));
 
 if ( '2' == $current_blog->deleted )
-		graceful_fail(sprintf(__('This blog has not been activated yet. If you are having problems activating your blog, please contact <a href="mailto:support@{%1$s}">support@{%1$s}</a>.'), $current_site->domain));
+		graceful_fail(sprintf(__('This blog has not been activated yet. If you are having problems activating your blog, please contact <a href="mailto:%1$s">%1$s</a>.'), get_site_option( 'admin_email', "support@{$current_site->domain}" )));
 
 if( $current_blog->archived == '1' )
     graceful_fail(__('This blog has been archived or suspended.'));
@@ -277,27 +351,76 @@ if( $current_blog->archived == '1' )
 if( $current_blog->spam == '1' )
     graceful_fail(__('This blog has been archived or suspended.'));
 
-if (!strstr($_SERVER['PHP_SELF'], 'install.php') && !strstr($_SERVER['PHP_SELF'], 'wp-admin/import')) :
-    // Used to guarantee unique hash cookies
-    $cookiehash = ''; // Remove in 1.4
-	define('COOKIEHASH', ''); 
-endif;
+define('COOKIEHASH', '');
 
+/**
+ * Should be exactly the same as the default value of SECRET_KEY in wp-config-sample.php
+ * @since 2.5
+ */
+$wp_default_secret_key = 'put your unique phrase here';
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.0.0
+ */
 if ( !defined('USER_COOKIE') )
 	define('USER_COOKIE', 'wordpressuser');
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.0.0
+ */
 if ( !defined('PASS_COOKIE') )
 	define('PASS_COOKIE', 'wordpresspass');
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.5
+ */
+if ( !defined('AUTH_COOKIE') )
+	define('AUTH_COOKIE', 'wordpress');
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.3.0
+ */
+if ( !defined('TEST_COOKIE') )
+	define('TEST_COOKIE', 'wordpress_test_cookie');
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 1.2.0
+ */
 if ( !defined('COOKIEPATH') )
 	define('COOKIEPATH', $current_site->path );
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 1.5.0
+ */
 if ( !defined('SITECOOKIEPATH') )
 	define('SITECOOKIEPATH', $current_site->path );
+
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.0.0
+ */
 if ( !defined('COOKIE_DOMAIN') )
 	define('COOKIE_DOMAIN', '.' . $current_site->domain);
+	
+/**
+ * It is possible to define this in wp-config.php
+ * @since 2.5.0
+ */
+if ( !defined( 'AUTOSAVE_INTERVAL' ) )
+	define( 'AUTOSAVE_INTERVAL', 60 );
+	
 
 require (ABSPATH . WPINC . '/vars.php');
 
 if ( !defined('PLUGINDIR') )
 	define('PLUGINDIR', 'wp-content/plugins'); // no leading slash, no trailing slash
+
 if ( get_option('active_plugins') ) {
 	$current_plugins = get_option('active_plugins');
 	if ( is_array($current_plugins) ) {
@@ -310,6 +433,16 @@ if ( get_option('active_plugins') ) {
 
 require (ABSPATH . WPINC . '/pluggable.php');
 
+/*
+ * In most cases the default internal encoding is latin1, which is of no use,
+ * since we want to use the mb_ functions for utf-8 strings
+ */
+if (function_exists('mb_internal_encoding')) {
+	if (!@mb_internal_encoding(get_option('blog_charset')))
+		mb_internal_encoding('UTF-8');
+}
+
+
 if ( defined('WP_CACHE') && function_exists('wp_cache_postload') )
 	wp_cache_postload();
 
@@ -330,19 +463,55 @@ $_SERVER = add_magic_quotes($_SERVER);
 
 do_action('sanitize_comment_cookies');
 
+/**
+ * WordPress Query object
+ * @global object $wp_the_query
+ * @since 2.0.0
+ */
 $wp_the_query =& new WP_Query();
+
+/**
+ * Holds the reference to @see $wp_the_query
+ * Use this global for WordPress queries
+ * @global object $wp_query
+ * @since 1.5.0
+ */
 $wp_query     =& $wp_the_query;
+
+/**
+ * Holds the WordPress Rewrite object for creating pretty URLs
+ * @global object $wp_rewrite
+ * @since 1.5.0
+ */
 $wp_rewrite   =& new WP_Rewrite();
+
+/**
+ * WordPress Object
+ * @global object $wp
+ * @since 2.0.0
+ */
 $wp           =& new WP();
 
-if( defined( "WP_INSTALLING" ) == false )
-	validate_current_theme();
+
+/**
+ * Web Path to the current active template directory
+ * @since 1.5
+ */
 define('TEMPLATEPATH', get_template_directory());
+
+/**
+ * Web Path to the current active template stylesheet directory
+ * @since 2.1
+ */
 define('STYLESHEETPATH', get_stylesheet_directory());
 
 // Load the default text localization domain.
 load_default_textdomain();
 
+/**
+ * The locale of the blog
+ * @since 1.5.0
+ */
 $locale = get_locale();
 $locale_file = ABSPATH . LANGDIR . "/$locale.php";
 if ( is_readable($locale_file) )
@@ -351,6 +520,11 @@ if ( is_readable($locale_file) )
 // Pull in locale data after loading text domain.
 require_once(ABSPATH . WPINC . '/locale.php');
 
+/**
+ * WordPress Locale object for loading locale domain date and various strings.
+ * @global object $wp_locale
+ * @since 2.1.0
+ */
 $wp_locale =& new WP_Locale();
 
 // Load functions for active theme.
@@ -359,12 +533,20 @@ if ( TEMPLATEPATH !== STYLESHEETPATH && file_exists(STYLESHEETPATH . '/functions
 if ( file_exists(TEMPLATEPATH . '/functions.php') )
 	include(TEMPLATEPATH . '/functions.php');
 
+/**
+ * shutdown_action_hook() - Runs just before PHP shuts down execution.
+ *
+ * @access private
+ * @since 1.2
+ */
 function shutdown_action_hook() {
 	do_action('shutdown');
 	wp_cache_close();
 }
 register_shutdown_function('shutdown_action_hook');
 
+$wp->init();  // Sets up current user.
+
 // Everything is loaded and initialized.
 do_action('init');
 
