@@ -201,11 +201,10 @@ function signup_another_blog($blog_id = '', $blog_title = '', $errors = '') {
 }
 
 function validate_another_blog_signup() {
-	global $current_user, $blog_id, $blog_title, $errors, $domain, $path;
+	global $wpdb, $current_user, $blog_id, $blog_title, $errors, $domain, $path;
 	$current_user = wp_get_current_user();
-	if( !is_user_logged_in() ) {
+	if( !is_user_logged_in() )
 		die();
-	}
 
 	$result = validate_blog_form();
 	extract($result);
@@ -218,13 +217,13 @@ function validate_another_blog_signup() {
 	$public = (int) $_POST['blog_public'];
 	$meta = apply_filters('signup_create_blog_meta', array ('lang_id' => 1, 'public' => $public));
 
-	wpmu_create_blog($domain, $path, $blog_title, $current_user->id, $meta);
+	wpmu_create_blog( $domain, $path, $blog_title, $current_user->id, $meta, $wpdb->siteid );
 	confirm_another_blog_signup($domain, $path, $blog_title, $current_user->user_login, $current_user->user_email, $meta);
 }
 
 function confirm_another_blog_signup($domain, $path, $blog_title, $user_name, $user_email, $meta) {
 ?>
-<h2><?php printf(__('The blog %s is yours.'), $domain.$path ) ?></h2>
+<h2><?php printf(__('The blog, %s, is yours.'), "<a href='http://{$domain}{$path}'>{$blog_title}</a>" ) ?></h2>
 <p><?php printf(__('<a href="http://%1$s">http://%2$s</a> is your new blog.  <a href="%3$s">Login</a> as "%4$s" using your existing password.'), $domain.$path, $domain.$path, "http://" . $domain.$path . "wp-login.php", $user_name) ?></p>
 <?php
 	do_action('signup_finished');
@@ -248,7 +247,6 @@ function signup_user($user_name = '', $user_email = '', $errors = '') {
 	$errors = $filtered_results['errors'];
 ?>
 <h2><?php printf( __('Get your own %s account in seconds'), $current_site->site_name ) ?></h2>
-<p><?php _e( "Fill out this one-step form and you'll be blogging seconds later!" ); ?></p>
 <form name="setupform" id="setupform" method="post" action="wp-signup.php">
 <input type="hidden" name="stage" value="validate-user-signup" />
 <?php do_action( "signup_hidden_fields" ); ?>
@@ -371,10 +369,17 @@ function validate_blog_signup() {
 
 function confirm_blog_signup($domain, $path, $blog_title, $user_name, $user_email, $meta) {
 ?>
-<h2><?php printf(__('The blog %s is yours'), $domain.$path) ?></h2>
+<h2><?php printf(__('Congratulations! Your new blog, %s, is almost ready.'), "<a href='http://{$domain}{$path}'>{$blog_title}</a>" ) ?></h2>
 <p><?php _e('But, before you can start using your blog, <strong>you must activate it</strong>.') ?></p>
-<p><?php printf(__('Check your inbox at <strong>%s</strong> and click the link given.  '),  $user_email) ?></p>
+<p><?php printf(__('Check your inbox at <strong>%s</strong> and click the link given. It should arrive within 30 minutes.'),  $user_email) ?></p>
 <p><?php _e('If you do not activate your blog within two days, you will have to sign up again.'); ?></p>
+<h2><?php _e('Still waiting for your email?') ?></h2>
+<p><?php _e("If you haven't received your email yet, there are a number of things you can do:") ?></p>
+<ul>
+<li><p><strong><?php _e('Wait a little longer.  Sometimes delivery of email can be delayed by precesses outside of our control.') ?></strong></p></li>
+<li><p><?php _e('Check the junk email or spam folder of your email client.  Sometime emails wind up there by mistake.') ?></p></li>
+<li><?php printf(__("Have you entered your email correctly?  We think it's %s but if you've entered it incorrectly, you won't receive it."), $user_email) ?></li>
+</ul>
 <?php
 	do_action('signup_finished');
 }
